function bistat(action)
% filename: bistat.m
% Project: POFACETS
% Description: This program implements the functionalities of the Calculate
%			Bistatic RCS GUI and computes the bistatic RCS of a selected model. 
% Author:  Prof. David C. Jenn and Elmo E. Garrido Jr.
% Date:   31 August 2000
% Place: NPS
% Last modifed: 11/17/00  (version 2.2)

global C
C = 3*10^8;	% speed of light in m/sec

switch(action)
   
	case 'ListB' 
      h_ListB = findobj(gcf, 'Tag','ListB');
      list = get(h_ListB,'String');
      v = get(gco,'Value');
      if (v == 1 | v == 2)
         set(h_ListB,'Value',3);
      end
                  
   case 'iTheta'   
      h_itheta = findobj(gcf,'Tag','iTheta'); 
      itheta_str = get(h_itheta,'String'); 
      itheta = getiAngle(itheta_str); 
      set(h_itheta,'String',num2str(itheta));

   case 'iPhi'
      h_iphi = findobj(gcf,'Tag','iPhi'); 
      iphi_str = get(h_iphi,'String'); 
      iphi = getiAngle(iphi_str); 
      set(h_iphi,'String',num2str(iphi));

   case 'TStart'
      h_tstart = findobj(gcf,'Tag','TStart'); 
      tstart_str = get(h_tstart,'String'); 
      tstart = getTStart(tstart_str); 
      set(h_tstart,'String',num2str(tstart));
      
   case 'TStop'
      h_tstop = findobj(gcf,'Tag','TStop'); 
      tstop_str = get(h_tstop,'String'); 
      tstop = getTStop(tstop_str); 
      set(h_tstop,'String',num2str(tstop));

   case 'Delt'
      h_delt = findobj(gcf,'Tag','Delt');
      delt_str = get(h_delt,'String'); 
      delt = getDelt(delt_str);
      set(h_delt,'String',num2str(delt));     
           
   case 'PStart'
      h_pstart = findobj(gcf,'Tag','PStart'); 
      pstart_str = get(h_pstart,'String'); 
      pstart = getPStart(pstart_str); 
      set(h_pstart,'String',num2str(pstart));

   case 'PStop'
      h_pstop = findobj(gcf,'Tag','PStop'); 
      pstop_str = get(h_pstop,'String'); 
      pstop = getPStop(pstop_str); 
      set(h_pstop,'String',num2str(pstop));

   case 'Delp'
      h_delp = findobj(gcf,'Tag','Delp');
      delp_str = get(h_delp,'String'); 
      delp = getDelp(delp_str);
      set(h_delp,'String',num2str(delp));     

   case 'LRegion'
      h_Lt = findobj(gcf,'Tag','LRegion');
      Lt_str = get(h_Lt,'String'); 
      Lt = getLRegion(Lt_str);
      set(h_Lt,'String',num2str(Lt));    
      
   case 'NTerms'
      h_Nt = findobj(gcf,'Tag','NTerms');
      Nt_str = get(h_Nt,'String'); 
      Nt = getNTerms(Nt_str);
      set(h_Nt,'String',num2str(Nt)); 
      
  	case 'i_pol'    
      h_ipol = findobj(gcf,'Tag','IncPolar'); 
      val = get(h_ipol,'Value');
      if val == 1
         Et = 1;
         Ep = 0;
      else
         Et = 0;
         Ep = 1;
      end
       
   case 'Freq'
      h_freq = findobj(gcf,'Tag','Freq');
      freq_str = get(h_freq,'String'); 
      freq = getFreq(freq_str);
      set(h_freq,'String',num2str(freq));     
      
	case 'Corr'
      h_corr = findobj(gcf,'Tag','Corr');
      corr_str = get(h_corr,'String');
      corr = getCorr(corr_str,C);
      set(h_corr,'String',num2str(corr));
  
   case 'Std'
      h_Std = findobj(gcf,'Tag','Std');
      std_str = get(h_Std,'String');
      std = getStd(std_str,C);
      set(h_Std,'String',num2str(std));
   
	case 'LoadFile'    
      h_ListB = findobj(gcf,'Tag','ListB');
      list = get(h_ListB,'String');
      v = get(h_ListB,'Value');
      name = list{v};
      msg = [name,' model selected.  Press Calculate RCS button ', ...
            'after setting all parameters.'];  
      Bmessage(msg);      
      
   case 'msg'
      delete(get(0,'CurrentFigure'));
		h_figs = get(0,'children');
		fig_exists = 0;
		for fig = h_figs'
		  	fig_exists = strcmp(get(fig,'Tag'),'bistatic');
		  	if fig_exists
            h_bistat = figure(fig);
            break;
  			end
		end      
		set(findobj(h_bistat,'Tag','Calculate'),'Enable','on');
      
   case 'Calculate'
    
      h_figs = get(0,'children');
		for fig = h_figs'
		  if strcmp(get(fig,'Tag'),'bistatic');
           h_bistat = fig;
		  end
		end

      h_ListB = findobj(gcf,'Tag','ListB');
      list = get(h_ListB,'String');
      v = get(h_ListB,'Value');
      name = list{v};
      msg = ['Computing the bistatic RCS of ',name,' model . . .'];         
		msgComputing(msg);
      pause(0.1);     
      
      % Get parameters
      itheta = str2num(get(findobj(h_bistat,'Tag','iTheta'),'String'));
      iphi   = str2num(get(findobj(h_bistat,'Tag','iPhi'),'String'));
      tstart = str2num(get(findobj(h_bistat,'Tag','TStart'),'String')); 
      tstop  = str2num(get(findobj(h_bistat,'Tag','TStop'),'String')); 
      delt   = str2num(get(findobj(h_bistat,'Tag','Delt'),'String')); 
      pstart = str2num(get(findobj(h_bistat,'Tag','PStart'),'String')); 
      pstop  = str2num(get(findobj(h_bistat,'Tag','PStop'),'String')); 
      delp   = str2num(get(findobj(h_bistat,'Tag','Delp'),'String')); 
      Lt     = str2num(get(findobj(h_bistat,'Tag','LRegion'),'String')); 
      Nt     = str2num(get(findobj(h_bistat,'Tag','NTerms'),'String'));       
      i_pol  = get(findobj(h_bistat,'Tag','IncPolar'),'Value');          
      freq	 = str2num(get(findobj(h_bistat,'Tag','Freq'),'String')); 
      wave   = C/(freq * 10^9);     
      bk     = 2*pi/wave;
      rad 	 = pi/180;    
      corr   = str2num(get(findobj(h_bistat,'Tag','Corr'),'String')); 
      corel	 = corr/wave; % normalized to the wavelength
      std    = str2num(get(findobj(h_bistat,'Tag','Std'),'String'));     
      delstd = std; 
      delsq  = delstd^2;  % variance
      cfac1  = exp(-4*bk^2*delsq);
      cfac2  = 4*pi*(bk*corel)^2*delsq;

      % Pattern loop
      cpi = cos(iphi*rad);  	spi = sin(iphi*rad);
      sti = sin(itheta*rad);	cti = cos(itheta*rad);
      ui = sti*cpi;		vi = sti*spi; 		wi = cti;
      D0i = [ui vi wi];
      uui = cti*cpi;		vvi = cti*spi;		wwi = -sti;
      Ri = - [ui vi wi]; 
      
		if tstart == tstop, thr0 = tstart*rad; end
      if pstart == pstop, phr0 = pstart*rad; end
	   it = floor((tstop-tstart)/delt) + 1;
   	ip = floor((pstop-pstart)/delp) + 1;
      % Incident wave polarization
      if i_pol == 1	
         Et = 1+j*0;
         Ep = 0+j*0;
      else					
	      Et = 0+j*0;  
         Ep = 1+j*0;  
      end    
  		% Wave amplitude at all vertices
		Co = 1;      
      % Get coordinates and facet data of model       
      cname = ['models',filesep,list{v},filesep,'coordinates.mat'];    
%      cname = ['models\',list{v},'\coordinates.mat'];    
		feval('load',cname);
      xpts = coordinates(:,1);
      ypts = coordinates(:,2);
      zpts = coordinates(:,3);
      nverts = length(xpts);
      % note : "facets" is a reserved word
      fname = ['models',filesep,list{v},filesep,'facet.mat'];
%      fname = ['models\',list{v},'\facet.mat'];     
      feval('load',fname); 
      nfc   = facet(:,1); 
      node1 = facet(:,2); 
      node2 = facet(:,3); 
      node3 = facet(:,4);
      % illumination flags for each triangle
      % Illumination flag : ilum=1 external face only defined by
      % right hand rule and CCW order of vertices
      ilum  = facet(:,5);	
   	Rs    = facet(:,6);	% resistivity of each triangle
      % turn off illumination test completely if iflag = 1 
      iflag = 0;
      ntria = length(node3);
      for i = 1:ntria 
			pts = [node1(i) node2(i) node3(i)];
		  	vind(i,:) = pts;       
		end
      x = xpts; y = ypts;  z = zpts;
      % Define position vectors to vertices
		for i = 1:nverts
			r(i,:) = [x(i) y(i) z(i)];
		end   
   	% Get edge vectors and normals from edge cross products
  		for i = 1:ntria
   		A = r(vind(i,2),:) - r(vind(i,1),:);
	   	B = r(vind(i,3),:) - r(vind(i,2),:);
		   C = r(vind(i,1),:) - r(vind(i,3),:);
         % compute outward normals from edge vectors
         N(i,:) = - cross(B,A);
			% Edge lengths for triangle "i"
   		d(i,1) = norm(A);
   		d(i,2) = norm(B);
		   d(i,3) = norm(C);
   		ss = .5*sum(d(i,:));
	   	Area(i) = sqrt(ss*(ss-d(i,1))*(ss-d(i,2))*(ss-d(i,3)));
	   	Nn = norm(N(i,:));
         % unit normals
         N(i,:) = N(i,:)/Nn;
         % rotation angles
         beta(i) = acos(N(i,3));  
         alpha(i) = atan2(N(i,2),N(i,1));
		end
      
      % Incident field in global Cartesian coordinates 
		e0(1) = uui*Et - spi*Ep;
		e0(2) = vvi*Et + cpi*Ep;
		e0(3) = wwi*Et;

   	for i1 = 1:ip
   		for i2 = 1:it
				phi(i1,i2) = pstart + (i1-1)*delp;
				phr = phi(i1,i2)*rad;
				theta(i1,i2) = tstart + (i2-1)*delt;
            thr = theta(i1,i2)*rad;
				% Global angles and direction cosine            
				st = sin(thr); 	ct = cos(thr);
   	      cp = cos(phr);		sp = sin(phr);
				u = st*cp; 			v = st*sp; 			w = ct ; 			D0=[u v w];
				U(i1,i2) = u; 		V(i1,i2) = v;		W(i1,i2) = w;
				uu = ct*cp; 		vv = ct*sp; 		ww = -st;
				% Spherical coordinate system outward radial unit vector
				R = [u v w];
				% Begin loop over triangles
				sumt 	= 0;
            sump 	= 0;
            sumdt = 0;
            sumdp = 0;
					         
      		for m = 1:ntria
               % If ilum = 1 only include face when front side is illuminated
               % normal dot ki= ri is positive
               ndotk  = N(m,:)*R.';
               nidotk = N(m,:)*Ri.';
               % Check to see if front face is illuminated
               if ((ilum(m) == 1 & nidotk >= 0) | ilum(m) == 0) | iflag == 1
                  % Check to see if front face is in view at the observation point
                  % (this is for diagnostic purposes -- should not be used in practice
                  % because then there would be no forward scattering!)
%                  if ((ilum(m) == 1 & ndotk >= 0) | ilum(m) == 0) | iflag == 1
							% Local direction cosines
                    	ca = cos(alpha(m)); 		sa = sin(alpha(m));  
                    	cb = cos(beta(m)); 		sb = sin(beta(m));
                     T1 = [ca sa 0; -sa ca 0; 0 0 1]; 
                     T2 = [cb 0 -sb; 0 1 0; sb 0 cb];
                   	% Transform incidence quantities
                    	D1i = T1*D0i.';
                  	D2i = T2*D1i;
	                 	ui2 = D2i(1); 		vi2 = D2i(2);  	wi2 = D2i(3);
							% Find incident spherical angles in local coordinates
                    	sti2 = sqrt(ui2^2 + vi2^2)*sign(wi2);  
                    	cti2 = sqrt(1 - sti2^2);
    						iphi2 = atan2(vi2,ui2+1e-10);
						  	thi2 = acos(cti2);
   	              	cpi2 = cos(iphi2); 
      	           	spi2 = sin(iphi2);
                    	% Transform observation quantities
                    	D1 = T1*D0.';
                    	D2 = T2*D1;
                    	u2 = D2(1); v2 = D2(2);  w2 = D2(3);
                    	st2 = sqrt(u2^2 + v2^2)*sign(w2);  
                    	ct2 = sqrt(1 - st2^2);
    						phi2 = atan2(v2,u2+1e-10);
						  	th2 = acos(ct2);
   	              	cp2 = cos(phi2); 
      	           	sp2 = sin(phi2);
                    	% Phase at the three vertices of triangle m; monostatic RCS needs "2"
            	   	Dp = bk*((x(vind(m,1)) - x(vind(m,3)))*(u+ui) + ...
               	       	   (y(vind(m,1)) - y(vind(m,3)))*(v+vi) + ...
                  	         (z(vind(m,1)) - z(vind(m,3)))*(w+wi));
	               	Dq = bk*((x(vind(m,2)) - x(vind(m,3)))*(u+ui) + ...
   	                    		(y(vind(m,2)) - y(vind(m,3)))*(v+vi) + ...
      	                   	(z(vind(m,2)) - z(vind(m,3)))*(w+wi));
         	      	Do = bk* (x(vind(m,3))*(u+ui) + y(vind(m,3))*(v+vi) + z(vind(m,3))*(w-wi));
							% Incident field in local Cartesian coordinates (stored in e2)
		     				e1 = T1*e0.';          
				     		e2 = T2*e1;
                     % Incident field in local spherical coordinates 
		     				Et2 =  e2(1)*cti2*cpi2 + e2(2)*cti2*spi2 - e2(3)*sti2;
						   Ep2 = -e2(1)*spi2 + e2(2)*cpi2;
							% Reflection coefficients (Rs is normalized to eta0)
		     				perp = -1/(2*Rs(m)*cti2 + 1);  	%local TE polarization
					     	para = 0;                			%local TM polarization
     						if (2*Rs(m) + cti2) ~=0 para = -cti2/(2*Rs(m) + cti2); end
							% Surface current components in local Cartesian coordinates
						   Jx2 = (-Et2*cpi2*para + Ep2*spi2*perp);  % cti2 removed
    						Jy2 = (-Et2*spi2*para - Ep2*cpi2*perp);  % cti2 removed
							% Area integral for general case
							DD = Dq - Dp;
							expDo = exp(j*Do);
							expDp = exp(j*Dp);
							expDq = exp(j*Dq);
							% Special case 1
   	  					if abs(Dp) < Lt & abs(Dq) >= Lt
      	   				sic=0.;
         					for n = 0:Nt
		      	    			sic = sic + (j*Dp)^n/fact(n)*(-Co/(n+1)+expDq*(Co*G(n,-Dq)));
         					end
         					Ic=sic*2*Area(m)*expDo/j/Dq;
							% Special case 2
		     				elseif abs(Dp) < Lt & abs(Dq) < Lt
	   	      			sic = 0.;
         					for n = 0:Nt
          						for nn = 0:Nt
            						sic = sic+(j*Dp)^n*(j*Dq)^nn/fact(nn+n+2)*Co;
          						end
         					end
	         				Ic = sic*2*Area(m)*expDo;
							% Special case 3
     						elseif abs(Dp) >= Lt & abs(Dq) < Lt
         					sic = 0.;
         					for n = 0:Nt
           						sic = sic+(j*Dq)^n/fact(n)*Co*G(n+1,-Dp)/(n+1);
         					end
         					Ic = sic*2*Area(m)*expDo*expDp;
							% Special case 4
   	  					elseif abs(Dp) >= Lt & abs(Dq) >= Lt & abs(DD) < Lt
      	   				sic = 0.;
         					for n = 0:Nt
           						sic = sic+(j*DD)^n/fact(n)*(-Co*G(n,Dq)+expDq*Co/(n+1));
         					end
	         				Ic = sic*2*Area(m)*expDo/j/Dq;
   	  					else
      	   				Ic = 2*Area(m)*expDo*(expDp*Co/Dp/DD-expDq*Co/Dq/DD-Co/Dp/Dq);
     						end   % end of special cases test
                       
                     % Add diffuse component
                     Edif = cfac2*Area(m)*ct2^2*exp(-(corel*pi*st2/wave)^2);                                         
                     % Scattered field components for triangle m in local coordinates
                     Es2(1) = Jx2*Ic; 	 Es2(2) = Jy2*Ic; 	Es2(3) = 0;
      					Ed2(1) = Jx2*Edif; Ed2(2) = Jy2*Edif;  Ed2(3) = 0;
							% Transform back to global coordinates, then sum field
	      				Es1 = T2.'*Es2.';
                     Es0 = T1.'*Es1;
                     Ed1 = T2.'*Ed2.'; 
                     Ed0 = T1.'*Ed1;
                     Ets =  uu*Es0(1) + vv*Es0(2) + ww*Es0(3);
      					Eps = -sp*Es0(1) + cp*Es0(2);
                     Etd =  uu*Ed0(1) + vv*Ed0(2) + ww*Ed0(3);
					      Epd = -sp*Ed0(1) + cp*Ed0(2);
                     % Sum over all triangles to get the total field
	      				sumt  = sumt  + Ets;
   	   				sump  = sump  + Eps;
                     sumdt = sumdt + abs(Etd);
                     sumdp = sumdp + abs(Epd);
%                  end	% end of ilum check
               end % end of view check                  
            end      % end of triangle loop
            Sth(i1,i2) = 10*log10(4*pi*cfac1*(abs(sumt)^2+sqrt(1-cfac1^2)*sumdt)/wave^2+1e-10);
            Sph(i1,i2) = 10*log10(4*pi*cfac1*(abs(sump)^2+sqrt(1-cfac1^2)*sumdp)/wave^2+1e-10);
%   	 		Sth(i1,i2) = 10*log10(4*pi*abs(sumt/wave)^2 + 1.e-10);
%    			Sph(i1,i2) = 10*log10(4*pi*abs(sump/wave)^2 + 1.e-10);
			end	% for i2 = 1:it 
   	end	% end of pattern loop (for i1 = 1:ip)
		% set plot range
   	Smax = max([max(max(Sth)),max(max(Sph))]);
      Lmax = (floor(Smax/5) + 1)*5; 
      Lmin = Lmax - 60;
   	Sth(:,:) = max(Sth(:,:),Lmin);
	   Sph(:,:) = max(Sph(:,:),Lmin);
         
      % delete msgComputing figure
      delete(get(0,'CurrentFigure'));
            
      if ip == 1	% phi-cut
         BPlot;
         plot(theta,Sth,theta,Sph,'--'); grid;
         title(['target: ',name,'  (thetai,phii): ','(',num2str(itheta),' ',num2str(iphi),') solid: theta  dashed: phi  phi= ',num2str(phi(1,1)),...
        '  wave (m): ',num2str(wave)]);
	   	xlabel('Bistatic Angle, theta (deg)');
   		ylabel('RCS (dBsm)');
			axis([min(theta),max(theta),Lmin,Lmax]);
		end
      
      if it == 1	% theta-cut
         BPlot;
         plot(phi,Sth,phi,Sph,'--'); grid;
         title(['target: ',name,'  (thetai,phii): ',' (',num2str(itheta),' ',num2str(iphi),') solid: theta  dashed: phi  theta= ',num2str(theta(1,1)),...
        '  wave (m): ',num2str(wave)])
	    	xlabel('Bistatic Angle, phi (deg)');
   	 	ylabel('RCS (dBsm)');
			axis([min(phi),max(phi),Lmin,Lmax]);
		end
   
   	if ip > 1 & it > 1
         Lv = [0,-20];
         BPlot1;
         subplot(121); 
%         meshc(U,V,Sth);    
         contour(U,V,Sth,Lv); 
         colorbar
			title('RCS-theta'); 
         axis([-1,1,-1,1])
		   axis square
         xlabel('U'); 
         ylabel('V'); 
         zlabel('RCS (dBsm)');
         
         subplot(122); 
%         meshc(U,V,Sph);
         contour(U,V,Sph,Lv)
         colorbar
			title('RCS-phi');
         axis([-1,1,-1,1])
			axis square
         xlabel('U'); 
         ylabel('V'); 
         zlabel('RCS (dBsm)');
		end
          
   case 'Close'       % Close all Bistatic GUIs         
      h_figs = get(0,'children');    
      for fig = h_figs'
         if strcmp(get(fig,'Tag'),'bistatic') | ...
      		strcmp(get(fig,'Tag'),'hlpbistat') | ...
      		strcmp(get(fig,'Tag'),'BMessage') | ...
				strcmp(get(fig,'Tag'),'BPlot') | ...
            strcmp(get(fig,'Tag'),'BPlot1')
         
            delete(fig); 
   		end         
	  end             
                  
   case 'Print'
      h_figs = get(0,'children');
		for fig = h_figs'
         if strcmp(get(fig,'Tag'),'bistatic')
            figure(fig);  
            print;
            break;
         end
      end   
      
end % switch


% validates theta and phi incident angle entered
function o_iang = getiAngle(ang_str)
   
   temp = str2num(ang_str);
   if (isempty(temp)) | (temp < -360) | (temp > 360)
      errordlg('Enter an incident angle between -360 and +360 degrees.', ...
         		'Incident Angle Status', 'error');
      temp = 45; % default incident angle
   elseif (ang_str == 'i' | ang_str == 'j')
      errordlg('Enter an incident angle between -360 and +360 degrees.', ...
         		'Incident Angle Status', 'error');
      temp = 45; % default incident angle
   end 
   o_iang = temp;
% end getiAngle  
      
% validates theta starting angle
function o_tstart = getTStart(start)    
  
  temp = str2num(start);
  if (isempty(temp)) | (temp < 0) | (temp > 360)
     errordlg('Enter a Theta Starting angle between 0 and 360 degrees.', ...
        		  'Theta Start Angle Status', 'error');
     temp = 0; % default theta start angle
  elseif (start == 'i' | start == 'j')
     errordlg('Enter a Theta Starting angle between 0 and 360 degrees.', ...
        		  'Theta Start Angle Status', 'error');
     temp = 0; % default theta start angle
  end 
  o_tstart = temp;
% end getTStart  
    
% validates theta ending angle
function o_tstop = getTStop(stop)   
  
  temp1 = str2num(stop);
  temp2 = str2num(get(findobj(gcf,'Tag','TStart'),'String'));
       
  if (isempty(temp1)) | (temp1 < 0) | (temp1 > 360)
     errordlg('Enter a Theta ending angle between starting angle and 360 degrees.', ...
        		  'Theta Stop Angle Status', 'error');
     temp1 = 180; 		% default theta stop angle
  elseif temp1 == temp2	% tstop angle = tstart angle
		set(findobj(gcf,'Tag','Delt'),'String',num2str(1));
      msgbox('For a theta-cut, increment is set to 1 degree.', ...
         	 'Theta-Cut Set','help');
  elseif (temp2 > temp1)   % theta stop less than theta start angle
     errordlg('Theta ending angle is less than starting angle!', ...
        		  'Theta Stop Angle Status','error'); 
     temp1 = 180; % default theta stop angle   
  elseif (stop == 'i' | stop == 'j')
     errordlg('Enter a Theta Ending angle between 0 and 360 degrees.', ...
        		  'Theta Stop Angle Status', 'error');
     temp1 = 180; % default theta ending angle
  end 
  o_tstop = temp1;
% end getTStop  
  
% validates theta increment angle
function o_delt = getDelt(inc)    
   temp3 = str2num(inc);
   temp1 = str2num(get(findobj(gcf,'Tag','TStart'),'String'));
   temp2 = str2num(get(findobj(gcf,'Tag','TStop'),'String'));
   del = temp2 - temp1;
   
   if temp1 == temp2 	% tstart == tstop
      if temp3 ~= 1
         msgbox('For a theta-cut, increment is set to 1 degree.', ...
            	 'Theta-Cut Set','help');
         del = 1;  % default value for theta-cut
      end
   elseif isempty(temp3) | (temp3 <= 0) | (temp3 > del)
      errordlg('Enter an increment angle less than the diference between starting and ending angles.', ...
         		'Angle Status', 'error');     
      del = 3;  % default theta increment angle
   elseif (inc == 'i' | inc == 'j')
      errordlg('Enter an increment angle less than the difference between starting and ending angle.', ...
         		'Angle Status', 'error');
      del = 3; % default theta increment angle
   else         
      del = temp3;
   end % if
   o_delt = del;
% end getDelt  
  
% validates phi starting angle
function o_pstart = getPStart(str) 
  
  temp = str2num(str);
  if (isempty(temp)) | temp < 0 | temp > 360
     errordlg('Enter a Phi Starting angle between 0 and 360 degrees.', ...
        		  'Angle Status', 'error');
     temp = 0; % default phi start angle
  elseif (str == 'i' | str == 'j')
     errordlg('Enter a Phi Starting angle between 0 and 360 degrees.', ...
        		  'Angle Status', 'error');
     temp = 0; % default phi start angle
  end 
  o_pstart = temp;
% end getPStart  
  
% validates phi ending angle 
function o_pstop = getPStop(stop)  
  
  temp1 = str2num(stop);
  temp2 = str2num(get(findobj(gcf,'Tag','PStart'),'String'));
  
  if (isempty(temp1)) | temp1 < 0 | temp1 > 360
     errordlg('Enter a Phi ending angle between starting angle and 360 degrees.', ...
        		  'Angle Status', 'error');
     temp1 = 180; 
  elseif temp1 == temp2 % pstop angle = pstart angle
		set(findobj(gcf,'Tag','Delp'),'String',num2str(1));
      msgbox('For a phi-cut, increment is set to 1 degree.', ...
         	 'Phi-Cut Set','help');        
  elseif temp2 > temp1   % phi start greater than phi stop angle
     errordlg('Phi ending angle is less than starting angle!', ...
        		  'Angle Status','error'); 
     temp1 = 180; % default phi ending angle
  elseif (stop == 'i' | stop == 'j')
     errordlg('Enter a Phi ending angle between 0 and 360 degrees.', ...
        		  'Angle Status', 'error');
     temp1 = 180; % default phi ending angle
  end 
  o_pstop = temp1;
% end getPStop  
  
% validates phi increment angle
function o_delp = getDelp(inc)   
  temp3 = str2num(inc);
  temp1 = str2num(get(findobj(gcf,'Tag','PStart'),'String'));
  temp2 = str2num(get(findobj(gcf,'Tag','PStop'),'String'));
  del = temp2 - temp1;
   
  if temp1 == temp2
     if (temp3 ~= 1)
        msgbox('For a phi-cut, increment is set to 1 degree.', ...
           		'Phi-Cut Set','help');
        del = 1;  % default value for phi-cut
     end     
  elseif isempty(temp3) | (temp3 <= 0) | (temp3 > del)
     errordlg('Enter an increment angle less than the diference between starting and ending angles.',...
        		  'Angle Status', 'error');         
     del = 3;  % default phi increment
  elseif (inc == 'i' | inc == 'j')
     errordlg('Enter an increment angle less than the diference between starting and ending angles.', ...
     			  'Angle Status', 'error');     
     del = 3; % default phi increment angle
  else
     del = temp3;
  end % if
  o_delp = del;
% end getDelp  
   
% validates Length of Taylor Series
function o_Lt = getLRegion(str)    
  
  	temp = str2num(str);
   if (isempty(temp)) | (temp <= 0) | (temp > 1)
      errordlg('Enter length of region between 0 and 1.', ...
         		'Taylor Series Region', 'error');
     temp = 0.05; % default length of Taylor series region
   end 
   o_Lt = temp;
% end getLRegion  
   
% validates Number of Terms in Taylor Series    
function o_Nt = getNTerms(str)   
  
   temp = str2num(str);
   if (isempty(temp)) | (floor(temp) <= 0)      
      errordlg('Enter a positive integer for the number of terms in the Taylor series.',...
         		'Taylor Series Terms', 'error');
      temp = 5; % default number of terms in Taylor series 
   elseif  floor(temp) > 10
      msgbox('Bistatic RCS computation for number of terms greater than 10 may take some time.',...
         	 'Taylor Series Terms','help');
      temp = floor(temp);
   end 
   o_Nt = temp;
% end getNTerms  
 
% validates frequency entered  
function o_Freq = getFreq(str)    
  
  	temp = str2num(str);
  	if (isempty(temp)) | (temp <= 0)      
        errordlg('Enter a positive frequency in Gigahertz.', ...
           		  'Frequency Status', 'error');
     	temp = 0.3; % default frequency 300 MHz  
  	elseif  temp > 10^5  % 100 THz
        errordlg('Laser radars have not been designed in this frequency range.', ...
           		  'Frequency Status', 'error');
     	temp = 0.3;
  	end 
  	o_Freq = temp;
% end getFreq  
     
% validates correlation entered
function o_Corr = getCorr(str,C)     
	freq = str2num(get(findobj(gcf,'Tag','Freq'),'String'));
   wave   = C/(freq * 10^9);

  	temp = str2num(str);
     
   if (isempty(temp)) | (temp < 0)   
   	temp = 0;	% default value for smooth surfaces
      errordlg('Enter a correlation distance from 0 to any positive value.', ...
         		'Correlation Distance Status', 'error');     
  	elseif (str == 'i' | str == 'j')
      errordlg('Enter a correlation distance from 0 to any positive value.', ...
           		  'Correlation Distance Status', 'error');
      temp = 0; % default value for smooth surface
  	elseif temp >= wave
        warndlg('Suggest that this value be smaller than the wavelength.', ...
           		 'Correlation Distance Status','warn');
      temp = temp;
  	end 
  	o_Corr = temp;
% end getCorr  
  
% validates standard deviation entered
function o_Std = getStd(str,C)     
	freq = str2num(get(findobj(gcf,'Tag','Freq'),'String'));
   wave   = C/(freq * 10^9);
    
  	temp = str2num(str);

  	if (isempty(temp)) | (temp < 0) 
      errordlg('Enter a standard deviation from 0 (smooth) to any positive value.', ...
         		'Standard Deviation Status', 'error');   
     	temp = 0; % default std. dev.      
   elseif (str == 'i' | str == 'j')
      errordlg('Enter a standard deviation from 0 (smooth) to any positive value.', ...
           		'Standard Deviation Status', 'error');    
     	temp = 0; % default std. dev.
  	elseif temp > (0.1*wave)  
      warndlg('Value entered is valid but extremely high.', ...
         	  'Standard Deviation Status','warn');
      temp = temp;
  	end 
  	o_Std = temp;
% end getStd