function dsgn(action)
% filename: dsgn.m
% Project: POFACETS
% Description: This function implements the functionalities of the DESIGN
%			MODEL GUIs (Coordinates and Facets).
% Author:  Prof. David C. Jenn and Elmo E. Garrido Jr.
% Date:  31 August 2000
% Place: NPS

 global facet ntria   	  
 global coord nvert scale

switch(action)         
   
	case 'NVert'    
      h_NVert = findobj(gcf,'Tag','NVert'); % get handle of nr. of vertices textframe
      NVert_str = get(gcbo,'String');   	  % get string in nr. of vertices textframe
      nvert = getNVert(NVert_str);  
      coord = zeros(nvert,3);
      set(h_NVert,'String',num2str(nvert));
      h_vc = createVarray(nvert);
      set(findobj(gcf,'Tag','Apply'),'enable','on');

	case 'scale'
		h_scale = findobj(gcf,'Tag','Scale'); % get handle of scale factor
      scale_str = get(gcbo,'String');   	  % get string in scale 
      scale = getScale(scale_str);  
      set(h_scale,'String',num2str(scale));
   
	case 'ListB'
      h_ListB = findobj(gcf,'Tag','ListB');
      list = get(h_ListB,'String');
      v = get(gco,'Value');
      if (v == 1 | v == 2)
         set(h_ListB,'Value',3);
      end      
   
	case 'CloseDesign'       % Close DESIGN, FACETS, MODEL and Help GUIs          
      h_figs = get(0,'children');
		for fig = h_figs'
         if strcmp(get(fig,'Tag'),'design') | ...
      		strcmp(get(fig,'Tag'),'facets') | ...
      		strcmp(get(fig,'Tag'),'model') | ...
				strcmp(get(fig,'Tag'),'hlpdsgncoord') | ...
            strcmp(get(fig,'Tag'),'hlpdsgnfacet') | ...
            strcmp(get(fig,'Tag'),'hlpmodel') | ...
            strcmp(get(fig,'Tag'),'dsgnFO') | ...
            strcmp(get(fig,'Tag'),'Save_As') | ...
            strcmp(get(fig,'Tag'),'Maximum Number of Points') | ...
            strcmp(get(fig,'Tag'),'Number of Vertices Status') | ...
            strcmp(get(fig,'Tag'),'Repl_File') 

		      delete(fig); 
   		end         
	  end             

   case 'Open'
      % 1 : get filename selected
		h_ListB = findobj(gcf,'Tag','ListB');
		list = get(h_ListB,'String');
		v = get(h_ListB,'Value');
		% 2 : delete Open Target Model File GUI  
		h_figs = get(0,'children');
		for fig = h_figs'
		    if strcmp(get(fig,'Tag'),'dsgnFO');
             delete(figure(fig));
             break;
		    end
      end
      dsgnFN;	% activate DESIGN GUI
      % 3 : get h of design
		h_figs = get(0,'children');
		for fig = h_figs'
		  if strcmp(get(fig,'Tag'),'design');
		      h_design = fig;
		  end
		end
		% 4 : display filename
		h_frame4 = uicontrol('Parent',h_design, ...
			'Units','normalized', ...
			'Backg',[0.8 0.8 0.8], ...
			'Position',[0.0268 0.93 0.26 .045], ...
			'Style','frame', ...
		   'Tag','Frame4');
		h_file = uicontrol('Parent',h_design, ...
			'Units','normalized', ...
			'Backg',[1 1 1], ...
	    	'Fontu','normalized', ...
	      'FontS',0.7, ...
   	   'Fontn','Arial', ...
			'Horiz','center', ...
			'Position',[0.03 0.935 0.255 0.0355], ...
			'String',[list{v}], ...
			'Style','text', ...
			'Tag','File');
		% 5 : load and display coordinates data, get scale factor   
		cname = ['models',filesep,list{v},filesep,'coordinates.mat'];            
%      cname = ['models\',list{v},'\coordinates.mat'];
      feval('load',cname);     
      xpts = coordinates(:,1);
      ypts = coordinates(:,2);
		zpts = coordinates(:,3);
      coord = [xpts ypts zpts];      
      nvert = length(xpts);         
      h_NVert = findobj(gcf,'Tag','NVert');
		set(h_NVert,'enable','on','String',num2str(nvert)); 
		h_vc = createVarray(nvert); 
		% 6 : display vertex coordinates
		for i = 1:nvert
		    set(h_vc(i,2),'String',xpts(i));
		    set(h_vc(i,3),'String',ypts(i));  
		    set(h_vc(i,4),'String',zpts(i));
		end
		set(findobj(gcf,'Tag','Apply'),'enable','on');
		% 6 : activate FACETS GUI, load and display facets data
		facets;
		% Facet table: face #,node1,node2,node3,ilum,R
		fname = ['models',filesep,list{v},filesep,'facet.mat'];      
%      fname = ['models\',list{v},'\facet.mat'];
		feval('load',fname);		         
		nfc   = facet(:,1);  % facet # 
      node1 = facet(:,2); 	
      node2 = facet(:,3); 
      node3 = facet(:,4);
      ilum  = facet(:,5);
      Rs		= facet(:,6);
      facet = [nfc node1 node2 node3 ilum Rs];
      ntria = length(node3);	% number of facets/triangles
       
      h_NFacet = findobj(gcf,'Tag','NFacet');
		set(h_NFacet,'String',num2str(ntria)); 
		h_fc = createFarray(ntria); 
           
      %  display facets data
		for i = 1:ntria
		    set(h_fc(i,2),'String',node1(i));
		    set(h_fc(i,3),'String',node2(i));  
		    set(h_fc(i,4),'String',node3(i));
  		    set(h_fc(i,5),'String',ilum(i));  
		    set(h_fc(i,6),'String',Rs(i));          
      end     
		set(findobj(gcf,'Tag','Apply'),'enable','on');
      set(findobj(gcf,'Tag','ViewModel'),'enable','on');
  		set(findobj(gcf,'Tag','u_ilum'),'enable','on');
		set(findobj(gcf,'Tag','u_Rs'),'enable','on');

		% activate VIEW GUI and display Model Geometry       
      model;
      for i  = 1:ntria 
			pts = [node1(i) node2(i) node3(i)];
			vind(i,:) = pts;       
		end
      x = xpts;
		y = ypts;
		z = zpts;
      % Define position vectors to vertices
      for i = 1:nvert
         r(i,:) = [x(i) y(i) z(i)];
      end  
      % get handle of figure Target Model Geometry, make it gcf
  		h_figs = get(0,'children');
		for fig = h_figs'
		  if strcmp(get(fig,'Tag'),'model');
		      figure(fig);
		  end
		end      
      h_axes = gca;          
      for i = 1:ntria
         X = [x(vind(i,1)) x(vind(i,2)) x(vind(i,3)) x(vind(i,1))];
    		Y = [y(vind(i,1)) y(vind(i,2)) y(vind(i,3)) y(vind(i,1))];
	    	Z = [z(vind(i,1)) z(vind(i,2)) z(vind(i,3)) z(vind(i,1))];
         plot3(X,Y,Z,'b')
		   if i == 1
     			hold on
	    	end
      end
      axis square
      title(['Triangular Surface of ',list{v},' Model']);
	   xlabel('x');
	   ylabel('y');
      zlabel('z');
      xmax = max(xpts); xmin = min(xpts); 
      ymax = max(ypts); ymin = min(ypts);
  		zmax = max(zpts); zmin = min(zpts);
      dmax = max([xmax ymax zmax]); 
      dmin = min([xmin ymin zmin]);
		% This is to avoid both a max and min of zero in any one dimension
	  	xmax = dmax; ymax = dmax; zmax = dmax;
      xmin = dmin; ymin = dmin; zmin = dmin;      
      axis([xmin, xmax, ymin, ymax, zmin, zmax])    
      
   case 'Apply' % Validate Coordinate Configuration, enable Design Facet pushbutton
      nvert = str2num(get(findobj(gcf,'Tag','NVert'),'String'));
      scale = str2num(get(findobj(gcf,'Tag','Scale'),'String'));
      coord = zeros(nvert,3);
      for i = 1:nvert
         for j = 1:3
            coord(i,j) = str2num(get(findobj(gcf,'Tag',['v',num2str(i),num2str(j+1)]),'String'));
         end
      end   
      valid = 0;    
      % check erroneous entries
      for i = 1:nvert
         for j = 1:3
            if coord(i,j) == 999999
               errordlg(['Error in coordinate(s) entered!', ...
                     '  Change value of coordinate(s) where 999999 is displayed.'],'Coordinate Status', 'error');
               valid = 1;
               break;  
            end % if                      
         end % for 
         if valid == 1
            break;
         end      
      end % for
      
      % check for duplicate vertices
      if valid == 0
         for i = 1:(nvert-1)
            for j = (i+1):nvert
               if coord(i,1) == coord(j,1) & coord(i,2) == coord(j,2) & coord(i,3) == coord(j,3)
            		errordlg('Duplicate vertex coordinates!', 'Coordinate Status', 'error');
                  valid = 1;            
                  break;
               end % if
            end % for
            if valid == 1
               break;
            end % if              
         end % for
      end % if
      
      if valid == 0
         set(findobj(gcf,'Tag','DesignFacets'),'Enable','on');
      	msgbox('Coordinates valid, press Design Facets button.','Coordinate Status', 'help');
      end
      
   case 'DesignFacets'      % activate FACET GUI
      facets;
     
   case 'v12'      
      h_v12 = findobj(gcf,'Tag','v12'); 
      c_str = get(gcbo,'String');   
      coord(1,1) = getCVal(c_str,h_v12);  
      set(h_v12,'String',coord(1,1));      
           
   case 'v13' 
      h_v13 = findobj(gcf,'Tag','v13'); 
      c_str = get(gcbo,'String');   
      coord(1,2) = getCVal(c_str,h_v13);  
      set(h_v13,'String',coord(1,2));     
      
   case 'v14'   
      h_v14 = findobj(gcf,'Tag','v14'); 
      c_str = get(gcbo,'String');   
      coord(1,3) = getCVal(c_str,h_v14);  
      set(h_v14,'String',coord(1,3));  
      
   case 'v22' 
      h_v22 = findobj(gcf,'Tag','v22'); 
      c_str = get(gcbo,'String');   
      coord(2,1) = getCVal(c_str,h_v22);  
      set(h_v22,'String',coord(2,1));        
      
   case 'v23' 
      h_v23 = findobj(gcf,'Tag','v23'); 
      c_str = get(gcbo,'String');   
      coord(2,2) = getCVal(c_str,h_v23);  
      set(h_v23,'String',coord(2,2));    
      
   case 'v24'
      h_v24 = findobj(gcf,'Tag','v24'); 
      c_str = get(gcbo,'String');   
      coord(2,3) = getCVal(c_str,h_v24);  
      set(h_v24,'String',coord(2,3));    
      
   case 'v32' 
      h_v32 = findobj(gcf,'Tag','v32'); 
      c_str = get(gcbo,'String');   
      coord(3,1) = getCVal(c_str,h_v32);  
      set(h_v32,'String',coord(3,1));        
      
   case 'v33' 
      h_v33 = findobj(gcf,'Tag','v33'); 
      c_str = get(gcbo,'String');   
      coord(3,2) = getCVal(c_str,h_v33);  
      set(h_v33,'String',coord(3,2));    
      
   case 'v34'
      h_v34 = findobj(gcf,'Tag','v34'); 
      c_str = get(gcbo,'String');   
      coord(3,3) = getCVal(c_str,h_v34);  
      set(h_v34,'String',coord(3,3));           
      
   case 'v42' 
      h_v42 = findobj(gcf,'Tag','v42'); 
      c_str = get(gcbo,'String');   
      coord(4,1) = getCVal(c_str,h_v42);  
      set(h_v42,'String',coord(4,1));        
      
   case 'v43' 
      h_v43 = findobj(gcf,'Tag','v43'); 
      c_str = get(gcbo,'String');   
      coord(4,2) = getCVal(c_str,h_v43);  
      set(h_v43,'String',coord(4,2));    
      
   case 'v44'
      h_v44 = findobj(gcf,'Tag','v44'); 
      c_str = get(gcbo,'String');   
      coord(4,3) = getCVal(c_str,h_v44);  
      set(h_v44,'String',coord(4,3));             
      
  case 'v52' 
      h_v52 = findobj(gcf,'Tag','v52'); 
      c_str = get(gcbo,'String');   
      coord(5,1) = getCVal(c_str,h_v52);  
      set(h_v52,'String',coord(5,1));        
      
   case 'v53' 
      h_v53 = findobj(gcf,'Tag','v53'); 
      c_str = get(gcbo,'String');   
      coord(5,2) = getCVal(c_str,h_v53);  
      set(h_v53,'String',coord(5,2));    
      
   case 'v54'
      h_v54 = findobj(gcf,'Tag','v54'); 
      c_str = get(gcbo,'String');   
      coord(5,3) = getCVal(c_str,h_v54);  
      set(h_v54,'String',coord(5,3));   
      
   case 'v62' 
      h_v62 = findobj(gcf,'Tag','v62'); 
      c_str = get(gcbo,'String');   
      coord(6,1) = getCVal(c_str,h_v62);  
      set(h_v62,'String',coord(6,1));        
      
   case 'v63' 
      h_v63 = findobj(gcf,'Tag','v63'); 
      c_str = get(gcbo,'String');   
      coord(6,2) = getCVal(c_str,h_v63);  
      set(h_v63,'String',coord(6,2));    
      
   case 'v64'
      h_v64 = findobj(gcf,'Tag','v64'); 
      c_str = get(gcbo,'String');   
      coord(6,3) = getCVal(c_str,h_v64);  
      set(h_v64,'String',coord(6,3));      
      
   case 'v72' 
      h_v72 = findobj(gcf,'Tag','v72'); 
      c_str = get(gcbo,'String');   
      coord(7,1) = getCVal(c_str,h_v72);  
      set(h_v72,'String',coord(7,1));        
      
   case 'v73' 
      h_v73 = findobj(gcf,'Tag','v73'); 
      c_str = get(gcbo,'String');   
      coord(7,2) = getCVal(c_str,h_v73);  
      set(h_v73,'String',coord(7,2));    
      
   case 'v74'
      h_v74 = findobj(gcf,'Tag','v74'); 
      c_str = get(gcbo,'String');   
      coord(7,3) = getCVal(c_str,h_v74);  
      set(h_v74,'String',coord(7,3));       
      
   case 'v82' 
      h_v82 = findobj(gcf,'Tag','v82'); 
      c_str = get(gcbo,'String');   
      coord(8,1) = getCVal(c_str,h_v82);  
      set(h_v82,'String',coord(8,1));        
      
   case 'v83' 
      h_v83 = findobj(gcf,'Tag','v83'); 
      c_str = get(gcbo,'String');   
      coord(8,2) = getCVal(c_str,h_v83);  
      set(h_v83,'String',coord(8,2));    
      
   case 'v84'
      h_v84 = findobj(gcf,'Tag','v84'); 
      c_str = get(gcbo,'String');   
      coord(8,3) = getCVal(c_str,h_v84);  
      set(h_v84,'String',coord(8,3));        
      
   case 'v92' 
      h_v92 = findobj(gcf,'Tag','v92'); 
      c_str = get(gcbo,'String');   
      coord(9,1) = getCVal(c_str,h_v92);  
      set(h_v92,'String',coord(9,1));        
      
   case 'v93' 
      h_v93 = findobj(gcf,'Tag','v93'); 
      c_str = get(gcbo,'String');   
      coord(9,2) = getCVal(c_str,h_v93);  
      set(h_v93,'String',coord(9,2));    
      
   case 'v94'   
      h_v94 = findobj(gcf,'Tag','v94'); 
      c_str = get(gcbo,'String');   
      coord(9,3) = getCVal(c_str,h_v94);  
      set(h_v94,'String',coord(9,3));   
      
   case 'v102' 
      h_v102 = findobj(gcf,'Tag','v102'); 
      c_str = get(gcbo,'String');   
      coord(10,1) = getCVal(c_str,h_v102);  
      set(h_v102,'String',coord(10,1));    
      
   case 'v103' 
      h_v103 = findobj(gcf,'Tag','v103'); 
      c_str = get(gcbo,'String');   
      coord(10,2) = getCVal(c_str,h_v103);  
      set(h_v103,'String',coord(10,2));    
      
   case 'v104'      
      h_v104 = findobj(gcf,'Tag','v104'); 
      c_str = get(gcbo,'String');   
      coord(10,3) = getCVal(c_str,h_v104);  
      set(h_v104,'String',coord(10,3));   
      
   case 'v112' 
      h_v112 = findobj(gcf,'Tag','v112'); 
      c_str = get(gcbo,'String');   
      coord(11,1) = getCVal(c_str,h_v112);  
      set(h_v112,'String',coord(11,1));    
      
   case 'v113' 
      h_v113 = findobj(gcf,'Tag','v113'); 
      c_str = get(gcbo,'String');   
      coord(11,2) = getCVal(c_str,h_v113);  
      set(h_v113,'String',coord(11,2));  
      
   case 'v114'
      h_v114 = findobj(gcf,'Tag','v114'); 
      c_str = get(gcbo,'String');   
      coord(11,3) = getCVal(c_str,h_v114);  
      set(h_v114,'String',coord(11,3)); 
      
   case 'v122' 
      h_v122 = findobj(gcf,'Tag','v122'); 
      c_str = get(gcbo,'String');   
      coord(12,1) = getCVal(c_str,h_v122);  
      set(h_v122,'String',coord(12,1));
      
   case 'v123' 
      h_v123 = findobj(gcf,'Tag','v123'); 
      c_str = get(gcbo,'String');   
      coord(12,2) = getCVal(c_str,h_v123);  
      set(h_v123,'String',coord(12,2)); 
      
   case 'v124'
      h_v124 = findobj(gcf,'Tag','v124'); 
      c_str = get(gcbo,'String');   
      coord(12,3) = getCVal(c_str,h_v124);  
      set(h_v124,'String',coord(12,3));  
      
   case 'v132' 
      h_v132 = findobj(gcf,'Tag','v132'); 
      c_str = get(gcbo,'String');   
      coord(13,1) = getCVal(c_str,h_v132);  
      set(h_v132,'String',coord(13,1));   
      
   case 'v133' 
      h_v133 = findobj(gcf,'Tag','v133'); 
      c_str = get(gcbo,'String');   
      coord(13,2) = getCVal(c_str,h_v133);  
      set(h_v133,'String',coord(13,2));   
      
   case 'v134'
      h_v134 = findobj(gcf,'Tag','v134'); 
      c_str = get(gcbo,'String');   
      coord(13,3) = getCVal(c_str,h_v134);  
      set(h_v134,'String',coord(13,3));  
      
   case 'v142' 
      h_v142 = findobj(gcf,'Tag','v142'); 
      c_str = get(gcbo,'String');   
      coord(14,1) = getCVal(c_str,h_v142);  
      set(h_v142,'String',coord(14,1));    
      
   case 'v143' 
      h_v143 = findobj(gcf,'Tag','v143'); 
      c_str = get(gcbo,'String');   
      coord(14,2) = getCVal(c_str,h_v143);  
      set(h_v143,'String',coord(14,2));   
      
   case 'v144'
      h_v144 = findobj(gcf,'Tag','v144'); 
      c_str = get(gcbo,'String');   
      coord(14,3) = getCVal(c_str,h_v144);  
      set(h_v144,'String',coord(14,3));     
      
   case 'v152' 
      h_v152 = findobj(gcf,'Tag','v152'); 
      c_str = get(gcbo,'String');   
      coord(15,1) = getCVal(c_str,h_v152);  
      set(h_v152,'String',coord(15,1));   
      
   case 'v153' 
      h_v153 = findobj(gcf,'Tag','v153'); 
      c_str = get(gcbo,'String');   
      coord(15,2) = getCVal(c_str,h_v153);  
      set(h_v153,'String',coord(15,2));  
      
   case 'v154'
      h_v154 = findobj(gcf,'Tag','v154'); 
      c_str = get(gcbo,'String');   
      coord(15,3) = getCVal(c_str,h_v154);  
      set(h_v154,'String',coord(15,3));   
      
   case 'v162' 
      h_v162 = findobj(gcf,'Tag','v162'); 
      c_str = get(gcbo,'String');   
      coord(16,1) = getCVal(c_str,h_v162);  
      set(h_v162,'String',coord(16,1));  
      
   case 'v163' 
      h_v163 = findobj(gcf,'Tag','v163'); 
      c_str = get(gcbo,'String');   
      coord(16,2) = getCVal(c_str,h_v163);  
      set(h_v163,'String',coord(16,2));    
      
   case 'v164'
      h_v164 = findobj(gcf,'Tag','v164'); 
      c_str = get(gcbo,'String');   
      coord(16,3) = getCVal(c_str,h_v164);  
      set(h_v164,'String',coord(16,3));  
      
   case 'v172' 
      h_v172 = findobj(gcf,'Tag','v172'); 
      c_str = get(gcbo,'String');   
      coord(17,1) = getCVal(c_str,h_v172);  
      set(h_v172,'String',coord(17,1));   
      
   case 'v173' 
      h_v173 = findobj(gcf,'Tag','v173'); 
      c_str = get(gcbo,'String');   
      coord(17,2) = getCVal(c_str,h_v173);  
      set(h_v173,'String',coord(17,2));  
      
   case 'v174'
      h_v174 = findobj(gcf,'Tag','v174'); 
      c_str = get(gcbo,'String');   
      coord(17,3) = getCVal(c_str,h_v174);  
      set(h_v174,'String',coord(17,3));   
      
   case 'v182' 
      h_v182 = findobj(gcf,'Tag','v182'); 
      c_str = get(gcbo,'String');   
      coord(18,1) = getCVal(c_str,h_v182);  
      set(h_v182,'String',coord(18,1));   
      
   case 'v183' 
      h_v183 = findobj(gcf,'Tag','v183'); 
      c_str = get(gcbo,'String');   
      coord(18,2) = getCVal(c_str,h_v183);  
      set(h_v183,'String',coord(18,2));    
      
   case 'v184'
      h_v184 = findobj(gcf,'Tag','v184'); 
      c_str = get(gcbo,'String');   
      coord(18,3) = getCVal(c_str,h_v184);  
      set(h_v184,'String',coord(18,3));    
      
   case 'v192' 
      h_v192 = findobj(gcf,'Tag','v192'); 
      c_str = get(gcbo,'String');   
      coord(19,1) = getCVal(c_str,h_v192);  
      set(h_v192,'String',coord(19,1));  
      
   case 'v193' 
      h_v193 = findobj(gcf,'Tag','v193'); 
      c_str = get(gcbo,'String');   
      coord(19,2) = getCVal(c_str,h_v193);  
      set(h_v193,'String',coord(19,2));    
      
   case 'v194'
      h_v194 = findobj(gcf,'Tag','v194'); 
      c_str = get(gcbo,'String');   
      coord(19,3) = getCVal(c_str,h_v194);  
      set(h_v194,'String',coord(19,3)); 
      
   case 'v202' 
      h_v202 = findobj(gcf,'Tag','v202'); 
      c_str = get(gcbo,'String');   
      coord(20,1) = getCVal(c_str,h_v202);  
      set(h_v202,'String',coord(20,1));    
      
   case 'v203' 
      h_v203 = findobj(gcf,'Tag','v203'); 
      c_str = get(gcbo,'String');   
      coord(20,2) = getCVal(c_str,h_v203);  
      set(h_v203,'String',coord(20,2));   
      
   case 'v204'
      h_v204 = findobj(gcf,'Tag','v204'); 
      c_str = get(gcbo,'String');   
      coord(20,3) = getCVal(c_str,h_v204);  
      set(h_v204,'String',coord(20,3));     
      
   case 'v212' 
      h_v212 = findobj(gcf,'Tag','v212'); 
      c_str = get(gcbo,'String');   
      coord(21,1) = getCVal(c_str,h_v212);  
      set(h_v212,'String',coord(21,1));     
      
   case 'v213' 
      h_v213 = findobj(gcf,'Tag','v213'); 
      c_str = get(gcbo,'String');   
      coord(21,2) = getCVal(c_str,h_v213);  
      set(h_v213,'String',coord(21,2));    
      
   case 'v214'
      h_v214 = findobj(gcf,'Tag','v214'); 
      c_str = get(gcbo,'String');   
      coord(21,3) = getCVal(c_str,h_v214);  
      set(h_v214,'String',coord(21,3));  
      
   case 'v222' 
      h_v222 = findobj(gcf,'Tag','v222'); 
      c_str = get(gcbo,'String');   
      coord(22,1) = getCVal(c_str,h_v222);  
      set(h_v222,'String',coord(22,1));   
      
   case 'v223' 
      h_v223 = findobj(gcf,'Tag','v223'); 
      c_str = get(gcbo,'String');   
      coord(22,2) = getCVal(c_str,h_v223);  
      set(h_v223,'String',coord(22,2)); 
      
   case 'v224'
      h_v224 = findobj(gcf,'Tag','v224'); 
      c_str = get(gcbo,'String');   
      coord(22,3) = getCVal(c_str,h_v224);  
      set(h_v224,'String',coord(22,3));     
      
   case 'v232' 
      h_v232 = findobj(gcf,'Tag','v232'); 
      c_str = get(gcbo,'String');   
      coord(23,1) = getCVal(c_str,h_v232);  
      set(h_v232,'String',coord(23,1));    
      
   case 'v233' 
      h_v233 = findobj(gcf,'Tag','v233'); 
      c_str = get(gcbo,'String');   
      coord(23,2) = getCVal(c_str,h_v233);  
      set(h_v233,'String',coord(23,2));  
      
   case 'v234'
      h_v234 = findobj(gcf,'Tag','v234'); 
      c_str = get(gcbo,'String');   
      coord(23,3) = getCVal(c_str,h_v234);  
      set(h_v234,'String',coord(23,3));  
      
   case 'v242' 
      h_v242 = findobj(gcf,'Tag','v242'); 
      c_str = get(gcbo,'String');   
      coord(24,1) = getCVal(c_str,h_v242);  
      set(h_v242,'String',coord(24,1));   
      
   case 'v243' 
      h_v243 = findobj(gcf,'Tag','v243'); 
      c_str = get(gcbo,'String');   
      coord(24,2) = getCVal(c_str,h_v243);  
      set(h_v243,'String',coord(24,2));
      
   case 'v244'
      h_v244 = findobj(gcf,'Tag','v244'); 
      c_str = get(gcbo,'String');   
      coord(24,3) = getCVal(c_str,h_v244);  
      set(h_v244,'String',coord(24,3));   
      
   case 'v252' 
      h_v252 = findobj(gcf,'Tag','v252'); 
      c_str = get(gcbo,'String');   
      coord(25,1) = getCVal(c_str,h_v252);  
      set(h_v252,'String',coord(25,1));   
      
   case 'v253' 
      h_v253 = findobj(gcf,'Tag','v253'); 
      c_str = get(gcbo,'String');   
      coord(25,2) = getCVal(c_str,h_v253);  
      set(h_v253,'String',coord(25,2));
      
   case 'v254'
      h_v254 = findobj(gcf,'Tag','v254'); 
      c_str = get(gcbo,'String');   
      coord(25,3) = getCVal(c_str,h_v254);  
      set(h_v254,'String',coord(25,3));  
      
   case 'v262' 
      h_v262 = findobj(gcf,'Tag','v262'); 
      c_str = get(gcbo,'String');   
      coord(26,1) = getCVal(c_str,h_v262);  
      set(h_v262,'String',coord(26,1));   
      
   case 'v263' 
      h_v263 = findobj(gcf,'Tag','v263'); 
      c_str = get(gcbo,'String');   
      coord(26,2) = getCVal(c_str,h_v263);  
      set(h_v263,'String',coord(26,2));   
      
   case 'v264'
      h_v264 = findobj(gcf,'Tag','v264'); 
      c_str = get(gcbo,'String');   
      coord(26,3) = getCVal(c_str,h_v264);  
      set(h_v264,'String',coord(26,3)); 
      
   case 'v272' 
      h_v272 = findobj(gcf,'Tag','v272'); 
      c_str = get(gcbo,'String');   
      coord(27,1) = getCVal(c_str,h_v272);  
      set(h_v272,'String',coord(27,1));
      
   case 'v273' 
      h_v273 = findobj(gcf,'Tag','v273'); 
      c_str = get(gcbo,'String');   
      coord(27,2) = getCVal(c_str,h_v273);  
      set(h_v273,'String',coord(27,2));  
      
   case 'v274'
      h_v274 = findobj(gcf,'Tag','v274'); 
      c_str = get(gcbo,'String');   
      coord(27,3) = getCVal(c_str,h_v274);  
      set(h_v274,'String',coord(27,3));  
      
   case 'v282' 
      h_v282 = findobj(gcf,'Tag','v282'); 
      c_str = get(gcbo,'String');   
      coord(28,1) = getCVal(c_str,h_v282);  
      set(h_v282,'String',coord(28,1));   
      
   case 'v283' 
      h_v283 = findobj(gcf,'Tag','v283'); 
      c_str = get(gcbo,'String');   
      coord(28,2) = getCVal(c_str,h_v283);  
      set(h_v283,'String',coord(28,2));   
      
   case 'v284'
      h_v284 = findobj(gcf,'Tag','v284'); 
      c_str = get(gcbo,'String');   
      coord(28,3) = getCVal(c_str,h_v284);  
      set(h_v284,'String',coord(28,3));     
      
   case 'v292' 
      h_v292 = findobj(gcf,'Tag','v292'); 
      c_str = get(gcbo,'String');   
      coord(29,1) = getCVal(c_str,h_v292);  
      set(h_v292,'String',coord(29,1));     
      
   case 'v293' 
      h_v293 = findobj(gcf,'Tag','v293'); 
      c_str = get(gcbo,'String');   
      coord(29,2) = getCVal(c_str,h_v293);  
      set(h_v293,'String',coord(29,2));    
      
   case 'v294'
      h_v294 = findobj(gcf,'Tag','v294'); 
      c_str = get(gcbo,'String');   
      coord(29,3) = getCVal(c_str,h_v294);  
      set(h_v294,'String',coord(29,3)); 
      
   case 'v302' 
      h_v302 = findobj(gcf,'Tag','v302'); 
      c_str = get(gcbo,'String');   
      coord(30,1) = getCVal(c_str,h_v302);  
      set(h_v302,'String',coord(30,1));    
      
   case 'v303' 
      h_v303 = findobj(gcf,'Tag','v303'); 
      c_str = get(gcbo,'String');   
      coord(30,2) = getCVal(c_str,h_v303);  
      set(h_v303,'String',coord(30,2));    
      
   case 'v304'
      h_v304 = findobj(gcf,'Tag','v304'); 
      c_str = get(gcbo,'String');   
      coord(30,3) = getCVal(c_str,h_v304);  
      set(h_v304,'String',coord(30,3));    
      
   case 'v312' 
      h_v312 = findobj(gcf,'Tag','v312'); 
      c_str = get(gcbo,'String');   
      coord(31,1) = getCVal(c_str,h_v312);  
      set(h_v312,'String',coord(31,1));  
      
   case 'v313' 
      h_v313 = findobj(gcf,'Tag','v313'); 
      c_str = get(gcbo,'String');   
      coord(31,2) = getCVal(c_str,h_v313);  
      set(h_v313,'String',coord(31,2));   
      
   case 'v314'
      h_v314 = findobj(gcf,'Tag','v314'); 
      c_str = get(gcbo,'String');   
      coord(31,3) = getCVal(c_str,h_v314);  
      set(h_v314,'String',coord(31,3));  
      
   case 'v322' 
      h_v322 = findobj(gcf,'Tag','v322'); 
      c_str = get(gcbo,'String');   
      coord(32,1) = getCVal(c_str,h_v322);  
      set(h_v322,'String',coord(32,1));    
      
   case 'v323' 
      h_v323 = findobj(gcf,'Tag','v323'); 
      c_str = get(gcbo,'String');   
      coord(32,2) = getCVal(c_str,h_v323);  
      set(h_v323,'String',coord(32,2));   
      
   case 'v324'
      h_v324 = findobj(gcf,'Tag','v324'); 
      c_str = get(gcbo,'String');   
      coord(32,3) = getCVal(c_str,h_v324);  
      set(h_v324,'String',coord(32,3));   
      
   case 'v332' 
      h_v332 = findobj(gcf,'Tag','v332'); 
      c_str = get(gcbo,'String');   
      coord(33,1) = getCVal(c_str,h_v332);  
      set(h_v332,'String',coord(33,1));     
      
   case 'v333' 
      h_v333 = findobj(gcf,'Tag','v333'); 
      c_str = get(gcbo,'String');   
      coord(33,2) = getCVal(c_str,h_v333);  
      set(h_v333,'String',coord(33,2));  
      
   case 'v344'
      h_v344 = findobj(gcf,'Tag','v344'); 
      c_str = get(gcbo,'String');   
      coord(34,3) = getCVal(c_str,h_v344);  
      set(h_v344,'String',coord(34,3));    
      
   case 'v352' 
      h_v352 = findobj(gcf,'Tag','v352'); 
      c_str = get(gcbo,'String');   
      coord(35,1) = getCVal(c_str,h_v352);  
      set(h_v352,'String',coord(35,1));     
      
   case 'v353' 
      h_v353 = findobj(gcf,'Tag','v353'); 
      c_str = get(gcbo,'String');   
      coord(35,2) = getCVal(c_str,h_v353);  
      set(h_v353,'String',coord(35,2));
      
   case 'v354'
      h_v354 = findobj(gcf,'Tag','v354'); 
      c_str = get(gcbo,'String');   
      coord(35,3) = getCVal(c_str,h_v354);  
      set(h_v354,'String',coord(35,3));  
      
   case 'v362' 
      h_v362 = findobj(gcf,'Tag','v362'); 
      c_str = get(gcbo,'String');   
      coord(36,1) = getCVal(c_str,h_v362);  
      set(h_v362,'String',coord(36,1));  
      
   case 'v363' 
      h_v363 = findobj(gcf,'Tag','v363'); 
      c_str = get(gcbo,'String');   
      coord(36,2) = getCVal(c_str,h_v363);  
      set(h_v363,'String',coord(36,2));  
      
   case 'v364'
      h_v364 = findobj(gcf,'Tag','v364'); 
      c_str = get(gcbo,'String');   
      coord(36,3) = getCVal(c_str,h_v364);  
      set(h_v364,'String',coord(36,3));    
      
   case 'v372' 
      h_v372 = findobj(gcf,'Tag','v372'); 
      c_str = get(gcbo,'String');   
      coord(37,1) = getCVal(c_str,h_v372);  
      set(h_v372,'String',coord(37,1)); 
      
   case 'v373' 
      h_v373 = findobj(gcf,'Tag','v373'); 
      c_str = get(gcbo,'String');   
      coord(37,2) = getCVal(c_str,h_v373);  
      set(h_v373,'String',coord(37,2));   
      
   case 'v374'
      h_v374 = findobj(gcf,'Tag','v374'); 
      c_str = get(gcbo,'String');   
      coord(37,3) = getCVal(c_str,h_v374);  
      set(h_v374,'String',coord(37,3));   
      
   case 'v382' 
      h_v382 = findobj(gcf,'Tag','v382'); 
      c_str = get(gcbo,'String');   
      coord(38,1) = getCVal(c_str,h_v382);  
      set(h_v382,'String',coord(38,1));    
      
   case 'v383' 
      h_v383 = findobj(gcf,'Tag','v383'); 
      c_str = get(gcbo,'String');   
      coord(38,2) = getCVal(c_str,h_v383);  
      set(h_v383,'String',coord(38,2));  
      
   case 'v384'
      h_v384 = findobj(gcf,'Tag','v384'); 
      c_str = get(gcbo,'String');   
      coord(38,3) = getCVal(c_str,h_v384);  
      set(h_v384,'String',coord(38,3));   
      
   case 'v392' 
      h_v392 = findobj(gcf,'Tag','v392'); 
      c_str = get(gcbo,'String');   
      coord(39,1) = getCVal(c_str,h_v392);  
      set(h_v392,'String',coord(39,1));    
      
   case 'v393' 
      h_v393 = findobj(gcf,'Tag','v393'); 
      c_str = get(gcbo,'String');   
      coord(39,2) = getCVal(c_str,h_v393);  
      set(h_v393,'String',coord(39,2));  
      
   case 'v394'
      h_v394 = findobj(gcf,'Tag','v394'); 
      c_str = get(gcbo,'String');   
      coord(39,3) = getCVal(c_str,h_v394);  
      set(h_v394,'String',coord(39,3));     
      
   case 'v402' 
      h_v402 = findobj(gcf,'Tag','v402'); 
      c_str = get(gcbo,'String');   
      coord(40,1) = getCVal(c_str,h_v402);  
      set(h_v402,'String',coord(40,1));     
      
   case 'v403' 
      h_v403 = findobj(gcf,'Tag','v403'); 
      c_str = get(gcbo,'String');   
      coord(40,2) = getCVal(c_str,h_v403);  
      set(h_v403,'String',coord(40,2));    
      
   case 'v404'
      h_v404 = findobj(gcf,'Tag','v404'); 
      c_str = get(gcbo,'String');   
      coord(40,3) = getCVal(c_str,h_v404);  
      set(h_v404,'String',coord(40,3));      
      
end % switch  

% validates the number of vertices entered
function o_nvert = getNVert(NVert_str)

	temp = str2num(NVert_str);
   if isempty(temp) | floor(temp) < 3
      VertStatus;
      temp = 3;
      set(findobj(gcf,'Tag','NVert'),'String',temp);
   elseif (NVert_str == 'i') | (NVert_str == 'j')
      VertStatus;
      temp == 3;
      set(findobj(gcf,'Tag','NVert'),'String',temp);
   elseif floor(temp) > 40
      MaxPoints;
      temp = 3;
      set(findobj(gcf,'Tag','NVert'),'String',temp);
   end
   o_nvert = temp;
      
	% validates the scale of vertices entered      
   function o_scale = getScale(scale_str)
   
   	temp = str2num(scale_str);
      
      if isempty(temp) | temp <= 0
         errordlg('Please check scale of vertices entered.','Scale Status','error');
         temp = 1;
      elseif (scale_str == 'i') | (scale_str == 'j')
         errordlg('Please check scale of vertices entered.','Scale Status','error');
         temp = 1;
      end
      o_scale = temp;
      
   % create array for boxes to accept user inputted coordinates      
   function h_vc = createVarray(verts)
   
   	% x-positions of text boxes wrt figure in left frame
	   tx1 = 0.03;   tx2 = 0.09;   tx3 = 0.225;   tx4 = 0.36;
   	% baseline y-position of text boxes wrt figure
	   ty = 0.855;  
	   % x-y dimensions of vertex number box
   	wx = 0.045;   wy = 0.036;
	 	% x-y dimensions of vertex coord box
   	vx = 0.12;    vy = 0.036;
	   % x-positions of text boxes wrt figure in right frame
	   fx1 = 0.51;   fx2 = 0.57;   fx3 = 0.705;   fx4 = 0.84;
 
	   if verts <=20
   	   a1 = array1(verts, tx1, tx2, tx3, tx4, ty, wx, wy, vx, vy);   % handle vertex coords (array)
      	h_vc = a1;
	   elseif verts <= 40
   	   a2 = array2(verts, tx1, tx2, tx3, tx4, ty, wx, wy, vx, vy, ...
      	   fx1, fx2, fx3, fx4);
	   	h_vc = a2;   
   	else
      	errordlg('Unexpected error!','ERROR', 'error');
	   end  % if
     
   % create up to 20 rows of vertex coordinates; store handles of the vertex edit boxes
   function a1 = array1(namv, tx1, tx2, tx3, tx4, ty, wx, wy, vx, vy)
      for i = 1:namv
         a1(i,1) = uicontrol('Units', 'normalized', ...
      	   'Position',[tx1 (ty-(i-1)*(0.04)) wx wy], ...
         	'Backg',[1 1 1], ...
	         'Fore', [0 0 0], ...
	         'Style','edit', ...
            'Fonts', 0.5, ...
            'Horiz', 'Right', ...
            'Callb',['dsgn ','v',num2str(i),num2str(1)], ...  
            'Tag',['v',num2str(i),'1']);
         set(a1(i,1),'String',num2str(i),'enable','off');         
	      a1(i,2) = uicontrol('Units', 'normalized', ...
   	      'Position',[tx2 (ty-(i-1)*(0.04)) vx vy], ...
      	   'Style','edit', ...
         	'Backg',[1 1 1], ...
	         'Fore', [0 0 0], ...
   	      'Fonts', 0.5, ...
            'Horiz', 'right', ...
            'String',0, ...
         	'Callb',['dsgn ','v',num2str(i),num2str(2)], ...
            'Tag',['v',num2str(i),'2']);              
         a1(i,3) = uicontrol('Units', 'normalized', ...
   	      'Position',[tx3 (ty-(i-1)*(0.04)) vx vy], ...
      	   'Style','edit', ...
         	'Backg',[1 1 1], ...
	         'Fore', [0 0 0], ...
   	      'Fonts', 0.5, ...
            'Horiz', 'right', ...
            'String',0, ...
         	'Callb',['dsgn ','v',num2str(i),num2str(3)], ...
            'Tag', ['v',num2str(i),'3']);         
         a1(i,4) = uicontrol('Units', 'normalized', ...
   	      'Position',[tx4 (ty-(i-1)*(0.04)) vx vy], ...
      	   'Style','edit', ...
         	'Backg',[1 1 1], ...
	         'Fore', [0 0 0], ...
   	      'Fonts', 0.5, ...
            'Horiz', 'right', ...
            'String',0, ...            
         	'Callb',['dsgn ','v',num2str(i),num2str(4)], ...
            'Tag', ['v',num2str(i),'4']);       
      end % for
            
   % create up to 40 rows of vertex coordinates
	function a2 = array2(numv, tx1, tx2, tx3, tx4, ty, wx, wy, vx, vy, ...
                     fx1, fx2, fx3, fx4);                  
      a1 = array1(20, tx1, tx2, tx3, tx4, ty, wx, wy, vx, vy);
      a2 = a1;
      for i = 21:numv
      	a2(i,1) = uicontrol('Units', 'normalized', ...
      		'Position',[fx1 (ty-(i-21)*(0.04)) wx wy], ...
         	'Backg',[1 1 1], ...
	         'Fore', [0 0 0], ...
	         'Style','edit', ...
   	      'Fonts', 0.5, ...
            'Horiz', 'Right', ...
         	'Callb',['dsgn ','v',num2str(i),num2str(1)], ...
         	'Tag',['v',num2str(i),'1']);
        	 set(a2(i,1),'String',num2str(i),'enable','off');
   	    a2(i,2) = uicontrol('Units', 'normalized', ...
      	   'Position',[fx2 (ty-(i-21)*(0.04)) vx vy], ...
      	   'Style','edit', ...
         	'Backg',[1 1 1], ...
	         'Fore', [0 0 0], ...
   	      'Fonts', 0.5, ...
            'Horiz', 'right', ...
            'String',0, ...            
         	'Callb',['dsgn ','v',num2str(i),num2str(2)], ...
            'Tag', ['v',num2str(i),'2']);             	     
          a2(i,3) = uicontrol('Units', 'normalized', ...
   	      'Position',[fx3 (ty-(i-21)*(0.04)) vx vy], ...
      	   'Style','edit', ...
         	'Backg',[1 1 1], ...
	         'Fore', [0 0 0], ...
   	      'Fonts', 0.5, ...
            'Horiz', 'right', ...
            'String',0, ...            
         	'Callb',['dsgn ','v',num2str(i),num2str(3)], ...
            'Tag', ['v',num2str(i),'3']);
		    a2(i,4) = uicontrol('Units', 'normalized', ...
   	      'Position',[fx4 (ty-(i-21)*(0.04)) vx vy], ...
      	   'Style','edit', ...
         	'Backg',[1 1 1], ...
	         'Fore', [0 0 0], ...
   	      'Fonts', 0.5, ...
            'Horiz', 'right', ...
            'String',0, ...            
         	'Callb',['dsgn ','v',num2str(i),num2str(4)], ...
            'Tag',['v',num2str(i),'4'] );        
      end % for
           
   % validate xyz coordinate values  
   function o_cval = getCVal(c_str,h_vc)      
   
   temp = str2num(c_str); 			
      
   if (isempty(temp))
      errordlg('Please check coordinate entered.','Coordinate Status','error');
      temp = 999999;             
     	set(h_vc,'String',999999);             
   elseif (c_str == 'i') | (c_str == 'j')
      errordlg('Please check coordinate entered.','Coordinate Status','error');
      temp = 999999;
     	set(h_vc,'String',999999);             
   end
   o_cval = temp; 

function h_fc = createFarray(nfc)
	% x-positions of text boxes wrt figure in left frame
   tx1 = 0.04; tx2 = 0.118; tx3 = 0.194; 
   tx4 = 0.271; tx5 = 0.35; tx6 = 0.423;    
   
   % baseline y-position of text boxes wrt figure
	ty = 0.856;  

	% x-y dimensions of facet number box
	wx = 0.0625;   wy = 0.034;    

	% x-positions of text boxes wrt figure in right frame
   fx1 = 0.52; fx2 = 0.595; fx3 = 0.675; 
   fx4 = 0.755; fx5 = 0.832; fx6 = 0.91;
  
	if nfc <=20
   	fa1 = farray1(nfc, tx1, tx2, tx3, tx4, tx5, tx6, ty, wx, wy);   
		h_fc = fa1;      
	elseif nfc <= 40
   	fa2 = farray2(nfc, tx1, tx2, tx3, tx4, tx5, tx6, ty, wx, wy,...
      	  			  fx1, fx2, fx3, fx4, fx5, fx6);
	   h_fc = fa2;         
   end  % if
           	    
function fa1 = farray1(nfc, tx1, tx2, tx3, tx4, tx5, tx6, ty, wx, wy)
	for i = 1:nfc
      fa1(i,1) = uicontrol('Units', 'normalized', ...
     	   'Position',[tx1 (ty-(i-1)*(0.04)) wx wy], ...
        	'Backg',[1 1 1], ...
	      'Fore', [0 0 0], ...
	      'Style','edit', ...
         'Fonts', 0.5, ...    
         'Callb',['fcets ','f',num2str(i),num2str(1)], ...  
			'Tag',['f',num2str(i),'1']);
      set(fa1(i,1),'String',num2str(i),'enable','off');         
	   fa1(i,2) = uicontrol('Units', 'normalized', ...
   	   'Position',[tx2 (ty-(i-1)*(0.04)) wx wy], ...
      	'Style','edit', ...
         'Backg',[1 1 1], ...
	      'Fore', [0 0 0], ...
   	   'Fonts', 0.5, ...
         'Callb',['fcets ','f',num2str(i),num2str(2)], ...  
			'Tag',['f',num2str(i),'2']);
      fa1(i,3) = uicontrol('Units', 'normalized', ...
   	   'Position',[tx3 (ty-(i-1)*(0.04)) wx wy], ...
      	'Style','edit', ...
         'Backg',[1 1 1], ...
	      'Fore', [0 0 0], ...
   	   'Fonts', 0.5, ...
         'Callb',['fcets ','f',num2str(i),num2str(3)], ...  
			'Tag',['f',num2str(i),'3']);
      fa1(i,4) = uicontrol('Units', 'normalized', ...
  	      'Position',[tx4 (ty-(i-1)*(0.04)) wx wy], ...
     	   'Style','edit', ...
        	'Backg',[1 1 1], ...
         'Fore', [0 0 0], ...
  	      'Fonts', 0.5, ...
         'Callb',['fcets ','f',num2str(i),num2str(4)], ...  
			'Tag',['f',num2str(i),'4']);
      fa1(i,5) = uicontrol('Units', 'normalized', ...
  	      'Position',[tx5 (ty-(i-1)*(0.04)) wx wy], ...
     	   'Style','edit', ...
        	'Backg',[1 1 1], ...
         'Fore', [0 0 0], ...
         'Fonts', 0.5, ...
         'Callb',['fcets ','f',num2str(i),num2str(5)], ...  
			'Tag',['f',num2str(i),'5']);
      fa1(i,6) = uicontrol('Units', 'normalized', ...
  	      'Position',[tx6 (ty-(i-1)*(0.04)) wx wy], ...
     	   'Style','edit', ...
        	'Backg',[1 1 1], ...
         'Fore', [0 0 0], ...
  	      'Fonts', 0.5, ...
         'Callb',['fcets ','f',num2str(i),num2str(6)], ...  
			'Tag',['f',num2str(i),'6']);
   end % for

function fa2 = farray2(nfc, tx1, tx2, tx3, tx4, tx5, tx6, ty, wx, wy, ...
                     fx1, fx2, fx3, fx4, fx5, fx6);

   fa1 = farray1(20, tx1, tx2, tx3, tx4, tx5, tx6, ty, wx, wy);
   fa2 = fa1;
	for i = 21:nfc
  	   fa2(i,1) = uicontrol('Units', 'normalized', ...
     	   'Position',[fx1 (ty-(i-21)*(0.04)) wx wy], ...
        	'Backg',[1 1 1], ...
         'Fore', [0 0 0], ...
         'Style','edit', ...
  	      'Fonts', 0.5, ...
         'Callb',['fcets ','f',num2str(i),num2str(1)], ...  
			'Tag',['f',num2str(i),'1']);
      set(fa2(i,1),'String',num2str(i),'enable','off');                           
      fa2(i,2) = uicontrol('Units', 'normalized', ...
  	      'Position',[fx2 (ty-(i-21)*(0.04)) wx wy], ...
     	   'Style','edit', ...
        	'Backg',[1 1 1], ...
         'Fore', [0 0 0], ...
	      'Fonts', 0.5, ...
         'Callb',['fcets ','f',num2str(i),num2str(2)], ...  
			'Tag',['f',num2str(i),'2']);
      fa2(i,3) = uicontrol('Units', 'normalized', ...
  	      'Position',[fx3 (ty-(i-21)*(0.04)) wx wy], ...
         'Style','edit', ...
        	'Backg',[1 1 1], ...
	      'Fore', [0 0 0], ...
   	   'Fonts', 0.5, ...
         'Callb',['fcets ','f',num2str(i),num2str(3)], ...  
			'Tag',['f',num2str(i),'3']);
      fa2(i,4) = uicontrol('Units', 'normalized', ...
   	   'Position',[fx4 (ty-(i-21)*(0.04)) wx wy], ...
         'Style','edit', ...
        	'Backg',[1 1 1], ...
	      'Fore', [0 0 0], ...
   	   'Fonts', 0.5, ...
         'Callb',['fcets ','f',num2str(i),num2str(4)], ...  
			'Tag',['f',num2str(i),'4']);
      fa2(i,5) = uicontrol('Units', 'normalized', ...
   	   'Position',[fx5 (ty-(i-21)*(0.04)) wx wy], ...
         'Style','edit', ...
        	'Backg',[1 1 1], ...
	      'Fore', [0 0 0], ...
         'Fonts', 0.5, ...
         'Callb',['fcets ','f',num2str(i),num2str(5)], ...  
			'Tag',['f',num2str(i),'5']);
		fa2(i,6) = uicontrol('Units', 'normalized', ...
   	   'Position',[fx6 (ty-(i-21)*(0.04)) wx wy], ...
         'Style','edit', ...
        	'Backg',[1 1 1], ...
	      'Fore', [0 0 0], ...
	  	   'Fonts', 0.5, ...
         'Callb',['fcets ','f',num2str(i),num2str(6)], ...  
			'Tag',['f',num2str(i),'6']);
   end % for