function fig = dsgnFO(command_str)
% filename: dsgnFO.m
% Project: POFACETS
% Description: This function displays a GUI that prompts the user to
%        select a model file to open.  The user may edit or scale,  
% 			and view the revised model geometry.
% Author:  Prof. David C. Jenn and Elmo E. Garrido Jr.
% Date:  31 August 2000
% Place: NPS
%
% 	DESIGN GUI
%  -- File 
%     -- Open ...


if nargin == 0
   command_str = 'initialize';
end

% Initialize the GUI
if strcmp(command_str,'initialize')
   h_figs = get(0,'children');
   fig_exists = 0;
   for fig = h_figs'
      fig_exists = strcmp(get(fig,'Tag'),'dsgnFO');
      if fig_exists
         figure(fig);
         return;
      end
   end
end

% Figure Window GUI
h0 = figure('Units','normalized', ...
	'Color',[0.8 0.8 0.8], ...
	'MenuBar','none', ...
	'Name','  Open Model File', ...
	'NumberTitle','off', ...
	'Position',[0.35 0.30 0.31 0.20], ...
	'Resize','off', ...
	'Tag','dsgnFO', ...
	'ToolBar','none');
% Text
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'FontS',0.7, ...
	'Horiz','left', ...
	'Position',[0.069 0.84 0.205 0.1234], ...
	'String','File Name:', ...
	'Style','text', ...
	'Tag','StaticText1');
% Pushbuttons Open File and Cancel
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'Callb','dsgn Open;', ...
	'FontS',0.3, ...
	'Position',[0.65 0.584 0.25 0.195], ...
	'String','Open', ...
	'Tag','Open');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'Callb','close(gcbf);', ...
	'FontS',0.27, ...
	'Position',[0.65 0.188 0.25 0.195], ...
	'String','Cancel', ...
	'Tag','Cancel');
% Listbox
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[1 1 1], ...
 	'Callb','dsgn ListB;', ...
 	'CreateFcn',['list = dir([''models'',filesep,''*.*'']);',...
					 'str = {list.name};',...
					 'set(gcbo,''String'',str)'],...   
   'FontS',0.087, ...
	'Position',[0.069 0.058 0.49 0.79], ...
	'Style','listbox', ...
	'Tag','ListB', ...
   'Value',3);