function fig = facets(command_str)
% filename: facets.m
% Project: POFACETS
% Description: This function displays the DESIGN TARGET MODEL Facets GUI.
% Author:  Prof. David C. Jenn and Elmo E. Garrido Jr.
% Date:  25 July 2000
% Place: NPS
%
% 	DESIGN MODEL FACETS GUI

if nargin == 0
   command_str = 'initialize';
end

% Initialize the GUI
if strcmp(command_str,'initialize')
   h_figs = get(0,'children');
   fig_exists = 0;
   for fig = h_figs'
      fig_exists = strcmp(get(fig,'Tag'),'facets');
      if fig_exists
         figure(fig);
         return;
      end
   end
end

% figure
h_facets = figure('Units','normalized', ...
	'Color',[0.8 0.8 0.8], ...
	'Name','   DESIGN MODEL Facets', ...
	'NumberTitle','off', ...
	'PaperPosition',[18 180 576 432], ...
	'PaperUnits','points', ...
	'Position',[0.44 0.22 0.547 0.648], ...
	'Resize','off', ...
   'MenuBar','none', ...
	'Tag','facets');
% Outer Frame
h1 = uicontrol('Parent',h_facets, ...
	'Units','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'Position',[0.0196 0.0763 0.977 0.916], ...
	'Style','frame', ...
	'Tag','Frame1');
% Text 
h1 = uicontrol('Parent',h_facets, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'FontS',0.8, ...
  	'FontN','Times-Roman', ...
	'FontW','bold', ...
	'Horiz','left', ...
	'Position',[0.035 0.95 0.25 0.03], ...
	'String','Number of Facets:', ...
	'Style','text', ...
	'Tag','StaticText1');
h1 = uicontrol('Parent',h_facets, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'FontN','Times-Roman', ...
	'FontS',0.8, ...
	'Horiz','left', ...
	'Position',[0.383 0.96 0.23 0.025], ...
	'String','Set uniform illumination:', ...
	'Style','text');
h1 = uicontrol('Parent',h_facets, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'FontN','Times-Roman', ...
	'FontS',0.8, ...
	'Horiz','left', ...
	'Position',[0.696 0.96 0.22 0.025], ...
	'String','Set uniform resistivity:', ...
	'Style','text', ...
	'Tag','StaticText3');
h1 = uicontrol('Parent',h_facets, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
   'FontN','Times-Roman', ...
	'FontS',0.9, ...
	'FontW','bold', ...
	'Horiz','left', ...
	'Position',[0.32 0.925 0.295 0.03], ...
	'String','FACET CONFIGURATION', ...
	'Style','text', ...
	'Tag','StaticText1');
h1 = uicontrol('Parent',h_facets, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
 	'FontN','Times-Roman', ...
	'FontS',0.7, ...   
	'Horiz','left', ...
	'Position',[0.035 0.891 0.43 0.0301], ...
	'String',' facet #    node1    node2     node3      ilum        Rs', ...
	'Style','text', ...
	'Tag','StaticText2');
h1 = uicontrol('Parent',h_facets, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'FontN','Times-Roman', ...
	'FontS',0.7, ...
	'Horiz','left', ...
	'Position',[0.52 0.891 0.433 0.0301], ...
	'String',' facet #   node1    node2     node3       ilum         Rs', ...
	'Style','text', ...
	'Tag','StaticText2');
% Editable Texts for u_ilum and Rs
h1 = uicontrol('Parent',h_facets, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[1 1 1], ...
	'Callb','fcets NFacet;', ...
   'FontS',0.6, ...
   'FontN','Times-Roman', ... 
	'Position',[0.24 0.94 0.067 0.043], ...
	'String','1', ...
	'Style','edit', ...
   'Tag','NFacet');
h1 = uicontrol('Parent',h_facets, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[1 1 1], ...
	'Callback','fcets u_Rs;', ...
	'FontN','Times-Roman', ...
   'Fonts', 0.6, ...
	'Position',[0.896 0.945 0.0625 0.04], ...
   'String','0', ...
   'Enable','off', ...
	'Style','edit', ...
	'Tag','u_Rs'); 
% PopUp
h1 = uicontrol('Parent',h_facets, ...
	'Units','normalized', ...
	'FontU','normalized', ...
   'Backg',[1 1 1], ...
 	'Callback','fcets u_ilum;', ...
	'FontN','Times-Roman', ...
	'FontS',0.8, ...
	'ListboxTop',0, ...
	'Position',[0.619 0.956 0.067 0.03], ...
   'String',['0';'1'], ...
   'Enable','off', ...
	'Style','popupmenu', ...
	'Tag','u_ilum', ...
	'Value',1);
% Two Inner Frames
h1 = uicontrol('Parent',h_facets, ...
	'Units','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'Position',[0.0232 0.0823 0.47857 0.811], ...
	'Style','frame', ...
	'Tag','Frame2');
h1 = uicontrol('Parent',h_facets, ...
	'Units','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'Position',[0.5095 0.0823 0.47857 0.811], ...
	'Style','frame', ...
	'Tag','Frame3');
% Pushbuttons View Model, Apply, Close, and Help
h1 = uicontrol('Parent',h_facets, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...    
	'Callb','fcets ViewModel;', ...
	'Enable','off', ...
	'FontN','Times-Roman', ...
	'FontS',0.5, ...
	'Position',[0.0536 0.012 0.19 0.055], ...  % was 0.175
	'String','View and Save', ...
	'Tag','ViewModel');
h1 = uicontrol('Parent',h_facets, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'Callb','fcets Apply;', ...
	'Enable','off', ...   
	'FontN','Times-Roman', ...
	'FontS',0.5, ...
	'Position',[0.30 0.012 0.175 0.055], ...
	'String','Apply', ...
	'Tag','Apply');
h1 = uicontrol('Parent',h_facets, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'Callb','fcets Close;', ...
	'FontN','Times-Roman', ...
	'FontS',0.5, ...
	'Position',[0.545 0.012 0.175 0.055], ...
	'String','Close', ...
	'Tag','Close');
h1 = uicontrol('Parent',h_facets, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'Callb','hlpdsgnfacet', ...
	'FontN','Times-Roman', ...
	'FontS',0.5, ...
	'Position',[0.789 0.012 0.175 0.055], ...
	'String','Help', ...
	'Tag','Help');