function fcets(action)
% filename: fcets.m
% Project: POFACETS
% Description: This program implements the functionalities of the Design
%		Model Facets GUI.  Node configuration of component facets of a model 
%		is defined including its illumination and resistivity characteristics.
% Author:  Prof. David C. Jenn and Elmo E. Garrido Jr.
% Date:  07 August 2000
% Place: NPS 
 
 global facet ntria   	  
 global coord nvert scale
 
switch(action)
      
   case 'NFacet'
      h_NFacet = findobj(gcf,'Tag','NFacet'); 
      ntria_str = get(gcbo,'String'); 
      ntria = getNFacet(ntria_str);                           
      set(h_NFacet,'String',ntria);      
      h_fc = createFarray(ntria);    
      facet = ones(ntria,6);    % initialize facet array 
      for i = 1:ntria
         facet(i,1) = i;
      end
      Rs = zeros(ntria,1);
      facet(:,6) = Rs;
      set(findobj(gcf,'Tag','u_ilum'),'enable','on');
      set(findobj(gcf,'Tag','u_Rs'),'enable','on');	            
      set(findobj(gcf,'Tag','Apply'),'enable','on');

	case 'u_ilum'    
      h_ilum = findobj(gcf,'Tag','u_ilum'); 
      val = get(h_ilum,'Value'); 
      if val == 1 		% ilum == 0
         % set ilum = 0 on all 5th column of facet
         for i = 1:ntria
            h = findobj(gcf, 'Tag',['f',num2str(i),'5']);
            set(h,'String',0);
         end
         ilum = zeros(ntria,1);
         facet(:,5) = ilum;
      elseif val == 2	% ilum == 1
         % set ilum = 1 on all 5th column of facet
         for i = 1:ntria
            h = findobj(gcf, 'Tag',['f',num2str(i),'5']);
             set(h,'String',1);
         end
         ilum = ones(ntria,1);
         facet(:,5) = ilum;         
      else
         errordlg('Value of illimination exceeds valid range.','Error','error');
      end
      
	case 'u_Rs' 
      ntria = str2num(get(findobj(gcf,'Tag','NFacet'),'String'));
      h_uRs = findobj(gcf,'Tag','u_Rs'); 
      uRs_str = get(gcbo,'String'); 
      u_Rs = getuRs(uRs_str);   
      set(h_uRs,'String',num2str(u_Rs));
      rs = zeros(ntria,1);
      % set uniform resistivity on all 6th column of facet
    	for i = 1:ntria
         h = findobj(gcf, 'Tag',['f',num2str(i),'6']);
         set(h,'String',num2str(u_Rs));
         rs(i,1) = u_Rs;   
      end
      facet(:,6) = rs;
	            
   case 'Apply'          
      valid = 0;	% assume valid            
      % check for uncorrected erroneous entries
      for i = 1:ntria 	
         for j = 1:4
            if facet(i,j+1) == 9999
               errordlg(['Error in node(s), illumination or resistivity entered!', ...
                     	 '  Correct entries where 9999 is displayed.'],'Node Status', 'error');
               valid = 1;
               break;  
            end % if                      
         end % for 
         if valid == 1
            break;
         end      
      end % for
      
      % check for duplicate nodes in a single facet
      if valid == 0
         for i = 1: ntria	 
          	if facet(i,2) == facet(i,3) | facet(i,2) == facet(i,4) ...
               		 | facet(i,3) == facet(i,4)
               errordlg('Duplicate nodes for the same facet number!','Node Status', 'error');
               valid = 1;                 
               break;
            end % if                      
	      end % for
      end % if
      
      % check for duplicate set of nodes on all facets
      if valid == 0
         for i = 1:(ntria-1)	 
            for j = (i+1): ntria
               if facet(i,2) == facet(j,2) & facet(i,3) == facet(j,3) & facet(i,4) == facet(j,4)
               	errordlg('Duplicate set of nodes for at least 2 facets!','Node Status', 'error');
                  valid = 1;
                  break
               end % if
            end % for
            if valid == 1
            	break;
         	end % if
         end % for
      end % if          
   
      if valid == 0
         set(findobj(gcf,'Tag','ViewModel'),'Enable','on');
         msgbox('All nodes, illumination, and resistivity values valid.  Click View Model button.','Facet Configuration Status', 'help');
      end                       
                 
   case 'ViewModel' 
      % 1 : find DESIGN GUI and get number of vertices
		h_figs = get(0,'children');
		for fig = h_figs'
		  if strcmp(get(fig,'Tag'),'design');
		      h_design = fig;
            figure(fig);	% make design the active figure    
        end
      end
      nvert = str2num(get(findobj(h_design,'Tag','NVert'),'String'));                    
      % check filename or model name      
      h_file = findobj(h_design,'Tag','File');   
      if h_file > 1
         name = get(h_file,'String');
      else
         name = 'New';
      end 
      % 2 : read coordinates data and scale factor
      coord = zeros(nvert,3);
      for i = 1:nvert
         for j = 1:3
            coord(i,j) = str2num(get(findobj(gcf,'Tag',['v',num2str(i),num2str(j+1)]),'String'));
         end
      end   
      scale = str2num(get(findobj(gcf,'Tag','Scale'),'String'));
      % 3 : find FACETS GUI and get number of triangles/facets
		h_figs = get(0,'children');
		for fig = h_figs'
		  if strcmp(get(fig,'Tag'),'facets');
		      h_facets = fig;
            figure(fig);	% make facets the active figure    
        end
      end
      ntria = str2num(get(findobj(h_facets,'Tag','NFacet'),'String'));                  
     % 4 : read facets data
      facet = zeros(ntria,6);
      for i = 1:ntria
         for j = 1:6
            facet(i,j) = str2num(get(findobj(gcf,'Tag',['f',num2str(i),num2str(j)]),'String'));
         end
      end
      % 5 : manipulate coordinates and facets data
		xpts = coord(:,1)*scale;
		ypts = coord(:,2)*scale;
		zpts = coord(:,3)*scale;
      
		nfc   = facet(:,1);  
      node1 = facet(:,2); 	
      node2 = facet(:,3); 
      node3 = facet(:,4);
      ilum  = facet(:,5);
      Rs		= facet(:,6);
      
      for i  = 1:ntria 
			pts = [node1(i) node2(i) node3(i)];
			vind(i,:) = pts;       
		end
      x = xpts; 	y = ypts; 	z = zpts;
                  
 		% Define position vectors to vertices
      for i = 1:nvert
        r(i,:) = [x(i) y(i) z(i)];
      end                                
      
      % 6: activate VIEW GUI and plot model             
      model;  
      for i = 1:ntria
         X = [x(vind(i,1)) x(vind(i,2)) x(vind(i,3)) x(vind(i,1))];
    		Y = [y(vind(i,1)) y(vind(i,2)) y(vind(i,3)) y(vind(i,1))];
	    	Z = [z(vind(i,1)) z(vind(i,2)) z(vind(i,3)) z(vind(i,1))];
         plot3(X,Y,Z,'b')
		   if i == 1
     			hold on
	    	end
      end      
      
      axis square   
      title(['Triangular Surface of ',name,' Model']);
	   xlabel('x');
	   ylabel('y');
      zlabel('z');
      xmax = max(xpts); xmin = min(xpts); 
      ymax = max(ypts); ymin = min(ypts);
  		zmax = max(zpts); zmin = min(zpts);
      dmax = max([xmax ymax zmax]); 
      dmin = min([xmin ymin zmin]);
		% This is to avoid both a max and min of zero in any one dimension
	  	xmax = dmax; 	ymax = dmax; 	zmax = dmax;
      xmin = dmin; 	ymin = dmin; 	zmin = dmin;      
      axis([xmin, xmax, ymin, ymax, zmin, zmax]);    

	case 'Close'    
      h_figs = get(0,'children');
		for fig = h_figs'
   		if strcmp(get(fig,'Tag'),'facets') | ...
      		strcmp(get(fig,'Tag'),'model') | ...
				strcmp(get(fig,'Tag'),'hlpdsgncoord') | ...
            strcmp(get(fig,'Tag'),'hlpdsgnfacet') | ...
            strcmp(get(fig,'Tag'),'hlpmodel') | ...
            strcmp(get(fig,'Tag'),'dsgnFO') | ...
            strcmp(get(fig,'Tag'),'SaveAs') | ...
            strcmp(get(fig,'Tag'),'Repl_File') 

		      delete(fig); 
   		end
		end             
     
   case 'f12'      
      h_f12 = findobj(gcf,'Tag','f12'); 
      f_str = get(gcbo,'String');   
      facet(1,2) = getFVal(f_str,h_f12);  
      set(h_f12,'String',facet(1,2));      
           
   case 'f13' 
      h_f13 = findobj(gcf,'Tag','f13'); 
      f_str = get(gcbo,'String');   
      facet(1,3) = getFVal(f_str,h_f13);  
      set(h_f13,'String',facet(1,3));     
      
   case 'f14'   
      h_f14 = findobj(gcf,'Tag','f14'); 
      f_str = get(gcbo,'String');   
      facet(1,4) = getFVal(f_str,h_f14);  
      set(h_f14,'String',facet(1,4));  
	% 5s are ilumination values      
   case 'f15'   
      h_f15 = findobj(gcf,'Tag','f15'); 
      f_str = get(gcbo,'String');   
      facet(1,5) = getIVal(f_str,h_f15);  
      set(h_f15,'String',facet(1,5));        
  % 6s are Resistivity values        
   case 'f16'   
      h_f16 = findobj(gcf,'Tag','f16'); 
      f_str = get(gcbo,'String');   
      facet(1,6) = getRVal(f_str,h_f16);  
      set(h_f16,'String',facet(1,6));        
      
   case 'f22' 
      h_f22 = findobj(gcf,'Tag','f22'); 
      f_str = get(gcbo,'String');   
      facet(2,2) = getFVal(f_str,h_f22);  
      set(h_f22,'String',facet(2,2));        
      
   case 'f23' 
      h_f23 = findobj(gcf,'Tag','f23'); 
      f_str = get(gcbo,'String');   
      facet(2,3) = getFVal(f_str,h_f23);  
      set(h_f23,'String',facet(2,3));    
      
   case 'f24'
      h_f24 = findobj(gcf,'Tag','f24'); 
      f_str = get(gcbo,'String');   
      facet(2,4) = getFVal(f_str,h_f24);  
      set(h_f24,'String',facet(2,4));    
	% 5s are ilumination values      
   case 'f25'   
      h_f25 = findobj(gcf,'Tag','f25'); 
      f_str = get(gcbo,'String');   
      facet(2,5) = getIVal(f_str,h_f25);  
      set(h_f25,'String',facet(2,5));        
  % 6s are Resistivity values        
   case 'f26'   
      h_f26 = findobj(gcf,'Tag','f26'); 
      f_str = get(gcbo,'String');   
      facet(2,6) = getRVal(f_str,h_f26);  
      set(h_f26,'String',facet(2,6));              
      
   case 'f32' 
      h_f32 = findobj(gcf,'Tag','f32'); 
      f_str = get(gcbo,'String');   
      facet(3,2) = getFVal(f_str,h_f32);  
      set(h_f32,'String',facet(3,2));        
      
   case 'f33' 
      h_f33 = findobj(gcf,'Tag','f33'); 
      f_str = get(gcbo,'String');   
      facet(3,3) = getFVal(f_str,h_f33);  
      set(h_f33,'String',facet(3,3));    
      
   case 'f34'
      h_f34 = findobj(gcf,'Tag','f34'); 
      f_str = get(gcbo,'String');   
      facet(3,4) = getFVal(f_str,h_f34);  
      set(h_f34,'String',facet(3,4));                 
	% 5s are ilumination values      
   case 'f35'   
      h_f35 = findobj(gcf,'Tag','f35'); 
      f_str = get(gcbo,'String');   
      facet(3,5) = getIVal(f_str,h_f35);  
      set(h_f35,'String',facet(3,5));        
  % 6s are Resistivity values        
   case 'f36'   
      h_f36 = findobj(gcf,'Tag','f36'); 
      f_str = get(gcbo,'String');   
      facet(3,6) = getRVal(f_str,h_f36);  
      set(h_f36,'String',facet(3,6));              
      
  case 'f42' 
      h_f42 = findobj(gcf,'Tag','f42'); 
      f_str = get(gcbo,'String');   
      facet(4,2) = getFVal(f_str,h_f42);  
      set(h_f42,'String',facet(4,2));        
      
   case 'f43' 
      h_f43 = findobj(gcf,'Tag','f43'); 
      f_str = get(gcbo,'String');   
      facet(4,3) = getFVal(f_str,h_f43);  
      set(h_f43,'String',facet(4,3));    
      
   case 'f44'
      h_f44 = findobj(gcf,'Tag','f44'); 
      f_str = get(gcbo,'String');   
      facet(4,4) = getFVal(f_str,h_f44);  
      set(h_f44,'String',facet(4,4));                   
	% 5s are ilumination values      
   case 'f45'   
      h_f45 = findobj(gcf,'Tag','f45'); 
      f_str = get(gcbo,'String');   
      facet(4,5) = getIVal(f_str,h_f45);  
      set(h_f45,'String',facet(4,5));        
  % 6s are Resistivity values        
   case 'f46'   
      h_f46 = findobj(gcf,'Tag','f46'); 
      f_str = get(gcbo,'String');   
      facet(4,6) = getRVal(f_str,h_f46);  
      set(h_f46,'String',facet(4,6));              
      
   case 'f52' 
      h_f52 = findobj(gcf,'Tag','f52'); 
      f_str = get(gcbo,'String');   
      facet(5,2) = getFVal(f_str,h_f52);  
      set(h_f52,'String',facet(5,2));        
      
   case 'f53' 
      h_f53 = findobj(gcf,'Tag','f53'); 
      f_str = get(gcbo,'String');   
      facet(5,3) = getFVal(f_str,h_f53);  
      set(h_f53,'String',facet(5,3));    
      
   case 'f54'
      h_f54 = findobj(gcf,'Tag','f54'); 
      f_str = get(gcbo,'String');   
      facet(5,4) = getFVal(f_str,h_f54);  
      set(h_f54,'String',facet(5,4));        
	% 5s are ilumination values      
   case 'f55'   
      h_f55 = findobj(gcf,'Tag','f55'); 
      f_str = get(gcbo,'String');   
      facet(5,5) = getIVal(f_str,h_f55);  
      set(h_f55,'String',facet(5,5));        
  % 6s are Resistivity values        
   case 'f56'   
      h_f56 = findobj(gcf,'Tag','f56'); 
      f_str = get(gcbo,'String');   
      facet(5,6) = getRVal(f_str,h_f56);  
      set(h_f56,'String',facet(5,6));              
      
   case 'f62' 
      h_f62 = findobj(gcf,'Tag','f62'); 
      f_str = get(gcbo,'String');   
      facet(6,2) = getFVal(f_str,h_f62);  
      set(h_f62,'String',facet(6,2));        
      
   case 'f63' 
      h_f63 = findobj(gcf,'Tag','f63'); 
      f_str = get(gcbo,'String');   
      facet(6,3) = getFVal(f_str,h_f63);  
      set(h_f63,'String',facet(6,3));    
      
   case 'f64'
      h_f64 = findobj(gcf,'Tag','f64'); 
      f_str = get(gcbo,'String');   
      facet(6,4) = getFVal(f_str,h_f64);  
      set(h_f64,'String',facet(6,4));                  
 	% 5s are ilumination values      
   case 'f65'   
      h_f65 = findobj(gcf,'Tag','f65'); 
      f_str = get(gcbo,'String');   
      facet(6,5) = getIVal(f_str,h_f65);  
      set(h_f65,'String',facet(6,5));        
  % 6s are Resistivity values        
   case 'f66'   
      h_f66 = findobj(gcf,'Tag','f66'); 
      f_str = get(gcbo,'String');   
      facet(6,6) = getRVal(f_str,h_f66);  
      set(h_f66,'String',facet(6,6));        
   
    case 'f72' 
      h_f72 = findobj(gcf,'Tag','f72'); 
      f_str = get(gcbo,'String');   
      facet(7,2) = getFVal(f_str,h_f72);  
      set(h_f72,'String',facet(7,2));        
      
    case 'f73' 
      h_f73 = findobj(gcf,'Tag','f73'); 
      f_str = get(gcbo,'String');   
      facet(7,3) = getFVal(f_str,h_f73);  
      set(h_f73,'String',facet(7,3));    
      
   case 'f74'
      h_f74 = findobj(gcf,'Tag','f74'); 
      f_str = get(gcbo,'String');   
      facet(7,4) = getFVal(f_str,h_f74);  
      set(h_f74,'String',facet(7,4));                  
 	% 5s are ilumination values      
   case 'f75'   
      h_f75 = findobj(gcf,'Tag','f75'); 
      f_str = get(gcbo,'String');   
      facet(7,5) = getIVal(f_str,h_f75);  
      set(h_f75,'String',facet(7,5));        
  % 6s are Resistivity values        
   case 'f76'   
      h_f76 = findobj(gcf,'Tag','f76'); 
      f_str = get(gcbo,'String');   
      facet(7,6) = getRVal(f_str,h_f76);  
      set(h_f76,'String',facet(7,6));        
   
   case 'f82' 
      h_f82 = findobj(gcf,'Tag','f82'); 
      f_str = get(gcbo,'String');   
      facet(8,2) = getFVal(f_str,h_f82);  
      set(h_f82,'String',facet(8,2));        
      
   case 'f83' 
      h_f83 = findobj(gcf,'Tag','f83'); 
      f_str = get(gcbo,'String');   
      facet(8,3) = getFVal(f_str,h_f83);  
      set(h_f83,'String',facet(8,3));    
      
   case 'f84'
      h_f84 = findobj(gcf,'Tag','f84'); 
      f_str = get(gcbo,'String');   
      facet(8,4) = getFVal(f_str,h_f84);  
      set(h_f84,'String',facet(8,4));                  
 	% 5s are ilumination values      
   case 'f85'   
      h_f85 = findobj(gcf,'Tag','f85'); 
      f_str = get(gcbo,'String');   
      facet(8,5) = getIVal(f_str,h_f85);  
      set(h_f85,'String',facet(8,5));        
  % 6s are Resistivity values        
   case 'f86'   
      h_f86 = findobj(gcf,'Tag','f86'); 
      f_str = get(gcbo,'String');   
      facet(8,6) = getRVal(f_str,h_f86);  
      set(h_f86,'String',facet(8,6));                 
   
   case 'f92' 
      h_f92 = findobj(gcf,'Tag','f92'); 
      f_str = get(gcbo,'String');   
      facet(9,2) = getFVal(f_str,h_f92);  
      set(h_f92,'String',facet(9,2));        
      
   case 'f93' 
      h_f93 = findobj(gcf,'Tag','f93'); 
      f_str = get(gcbo,'String');   
      facet(9,3) = getFVal(f_str,h_f93);  
      set(h_f93,'String',facet(9,3));    
      
   case 'f94'
      h_f94 = findobj(gcf,'Tag','f94'); 
      f_str = get(gcbo,'String');   
      facet(9,4) = getFVal(f_str,h_f94);  
      set(h_f94,'String',facet(9,4));                  
 	% 5s are ilumination values      
   case 'f95'   
      h_f95 = findobj(gcf,'Tag','f95'); 
      f_str = get(gcbo,'String');   
      facet(9,5) = getIVal(f_str,h_f95);  
      set(h_f95,'String',facet(9,5));        
  % 6s are Resistivity values        
   case 'f96'   
      h_f96 = findobj(gcf,'Tag','f96'); 
      f_str = get(gcbo,'String');   
      facet(9,6) = getRVal(f_str,h_f96);  
      set(h_f96,'String',facet(9,6));        
   
   case 'f102' 
      h_f102 = findobj(gcf,'Tag','f102'); 
      f_str = get(gcbo,'String');   
      facet(10,2) = getFVal(f_str,h_f102);  
      set(h_f102,'String',facet(10,2));        
      
   case 'f103' 
      h_f103 = findobj(gcf,'Tag','f103'); 
      f_str = get(gcbo,'String');   
      facet(10,3) = getFVal(f_str,h_f103);  
      set(h_f103,'String',facet(10,3));    
      
   case 'f104'
      h_f104 = findobj(gcf,'Tag','f104'); 
      f_str = get(gcbo,'String');   
      facet(10,4) = getFVal(f_str,h_f104);  
      set(h_f104,'String',facet(10,4));                  
 	% 5s are ilumination values      
   case 'f105'   
      h_f105 = findobj(gcf,'Tag','f105'); 
      f_str = get(gcbo,'String');   
      facet(10,5) = getIVal(f_str,h_f105);  
      set(h_f105,'String',facet(10,5));        
  % 6s are Resistivity values        
   case 'f106'   
      h_f106 = findobj(gcf,'Tag','f106'); 
      f_str = get(gcbo,'String');   
      facet(10,6) = getRVal(f_str,h_f106);  
      set(h_f106,'String',facet(10,6));        
   
   case 'f112' 
      h_f112 = findobj(gcf,'Tag','f112'); 
      f_str = get(gcbo,'String');   
      facet(11,2) = getFVal(f_str,h_f112);  
      set(h_f112,'String',facet(11,2));        
      
   case 'f113' 
      h_f113 = findobj(gcf,'Tag','f113'); 
      f_str = get(gcbo,'String');   
      facet(11,3) = getFVal(f_str,h_f113);  
      set(h_f113,'String',facet(11,3));    
      
   case 'f114'
      h_f114 = findobj(gcf,'Tag','f114'); 
      f_str = get(gcbo,'String');   
      facet(11,4) = getFVal(f_str,h_f114);  
      set(h_f114,'String',facet(11,4));                  
 	% 5s are ilumination values      
   case 'f115'   
      h_f115 = findobj(gcf,'Tag','f115'); 
      f_str = get(gcbo,'String');   
      facet(11,5) = getIVal(f_str,h_f115);  
      set(h_f115,'String',facet(11,5));        
  % 6s are Resistivity values        
   case 'f116'   
      h_f116 = findobj(gcf,'Tag','f116'); 
      f_str = get(gcbo,'String');   
      facet(11,6) = getRVal(f_str,h_f116);  
      set(h_f116,'String',facet(11,6));        
      
   case 'f122' 
      h_f122 = findobj(gcf,'Tag','f122'); 
      f_str = get(gcbo,'String');   
      facet(12,2) = getFVal(f_str,h_f122);  
      set(h_f122,'String',facet(12,2));        
      
   case 'f123' 
      h_f123 = findobj(gcf,'Tag','f123'); 
      f_str = get(gcbo,'String');   
      facet(12,3) = getFVal(f_str,h_f123);  
      set(h_f123,'String',facet(12,3));    
      
   case 'f124'
      h_f124 = findobj(gcf,'Tag','f124'); 
      f_str = get(gcbo,'String');   
      facet(12,4) = getFVal(f_str,h_f124);  
      set(h_f124,'String',facet(12,4));                  
 	% 5s are ilumination values      
   case 'f125'   
      h_f125 = findobj(gcf,'Tag','f125'); 
      f_str = get(gcbo,'String');   
      facet(12,5) = getIVal(f_str,h_f125);  
      set(h_f125,'String',facet(12,5));        
  % 6s are Resistivity values        
   case 'f126'   
      h_f126 = findobj(gcf,'Tag','f126'); 
      f_str = get(gcbo,'String');   
      facet(12,6) = getRVal(f_str,h_f126);  
      set(h_f126,'String',facet(12,6));        
   
   case 'f132' 
      h_f132 = findobj(gcf,'Tag','f132'); 
      f_str = get(gcbo,'String');   
      facet(13,2) = getFVal(f_str,h_f132);  
      set(h_f132,'String',facet(13,2));        
      
   case 'f133' 
      h_f133 = findobj(gcf,'Tag','f133'); 
      f_str = get(gcbo,'String');   
      facet(13,3) = getFVal(f_str,h_f133);  
      set(h_f133,'String',facet(13,3));    
      
   case 'f134'
      h_f134 = findobj(gcf,'Tag','f134'); 
      f_str = get(gcbo,'String');   
      facet(13,4) = getFVal(f_str,h_f134);  
      set(h_f134,'String',facet(13,4));                  
 	% 5s are ilumination values      
   case 'f135'   
      h_f135 = findobj(gcf,'Tag','f135'); 
      f_str = get(gcbo,'String');   
      facet(13,5) = getIVal(f_str,h_f135);  
      set(h_f135,'String',facet(13,5));        
  % 6s are Resistivity values        
   case 'f136'   
      h_f136 = findobj(gcf,'Tag','f136'); 
      f_str = get(gcbo,'String');   
      facet(13,6) = getRVal(f_str,h_f136);  
      set(h_f136,'String',facet(13,6));        
   
   case 'f142' 
      h_f142 = findobj(gcf,'Tag','f142'); 
      f_str = get(gcbo,'String');   
      facet(14,2) = getFVal(f_str,h_f142);  
      set(h_f142,'String',facet(14,2));        
      
   case 'f143' 
      h_f143 = findobj(gcf,'Tag','f143'); 
      f_str = get(gcbo,'String');   
      facet(14,3) = getFVal(f_str,h_f143);  
      set(h_f143,'String',facet(14,3));    
      
   case 'f144'
      h_f144 = findobj(gcf,'Tag','f144'); 
      f_str = get(gcbo,'String');   
      facet(14,4) = getFVal(f_str,h_f144);  
      set(h_f144,'String',facet(14,4));                  
 	% 5s are ilumination values      
   case 'f145'   
      h_f145 = findobj(gcf,'Tag','f145'); 
      f_str = get(gcbo,'String');   
      facet(14,5) = getIVal(f_str,h_f145);  
      set(h_f145,'String',facet(14,5));        
  % 6s are Resistivity values        
   case 'f146'   
      h_f146 = findobj(gcf,'Tag','f146'); 
      f_str = get(gcbo,'String');   
      facet(14,6) = getRVal(f_str,h_f146);  
      set(h_f146,'String',facet(14,6));        
   
   case 'f152' 
      h_f152 = findobj(gcf,'Tag','f152'); 
      f_str = get(gcbo,'String');   
      facet(15,2) = getFVal(f_str,h_f152);  
      set(h_f152,'String',facet(15,2));        
      
   case 'f153' 
      h_f153 = findobj(gcf,'Tag','f153'); 
      f_str = get(gcbo,'String');   
      facet(15,3) = getFVal(f_str,h_f153);  
      set(h_f153,'String',facet(15,3));    
      
   case 'f154'
      h_f154 = findobj(gcf,'Tag','f154'); 
      f_str = get(gcbo,'String');   
      facet(15,4) = getFVal(f_str,h_f154);  
      set(h_f154,'String',facet(15,4));                  
 	% 5s are ilumination values      
   case 'f155'   
      h_f155 = findobj(gcf,'Tag','f155'); 
      f_str = get(gcbo,'String');   
      facet(15,5) = getIVal(f_str,h_f155);  
      set(h_f155,'String',facet(15,5));        
  % 6s are Resistivity values        
   case 'f156'   
      h_f156 = findobj(gcf,'Tag','f156'); 
      f_str = get(gcbo,'String');   
      facet(15,6) = getRVal(f_str,h_f156);  
      set(h_f156,'String',facet(15,6));        

    case 'f162' 
      h_f162 = findobj(gcf,'Tag','f162'); 
      f_str = get(gcbo,'String');   
      facet(16,2) = getFVal(f_str,h_f162);  
      set(h_f162,'String',facet(16,2));        
      
   case 'f163' 
      h_f163 = findobj(gcf,'Tag','f163'); 
      f_str = get(gcbo,'String');   
      facet(16,3) = getFVal(f_str,h_f163);  
      set(h_f163,'String',facet(16,3));    
      
   case 'f164'
      h_f164 = findobj(gcf,'Tag','f164'); 
      f_str = get(gcbo,'String');   
      facet(16,4) = getFVal(f_str,h_f164);  
      set(h_f164,'String',facet(16,4));                  
 	% 5s are ilumination values      
   case 'f165'   
      h_f165 = findobj(gcf,'Tag','f165'); 
      f_str = get(gcbo,'String');   
      facet(16,5) = getIVal(f_str,h_f165);  
      set(h_f165,'String',facet(16,5));        
  % 6s are Resistivity values        
   case 'f166'   
      h_f166 = findobj(gcf,'Tag','f166'); 
      f_str = get(gcbo,'String');   
      facet(16,6) = getRVal(f_str,h_f166);  
      set(h_f166,'String',facet(16,6));        
     
   case 'f172' 
      h_f172 = findobj(gcf,'Tag','f172'); 
      f_str = get(gcbo,'String');   
      facet(17,2) = getFVal(f_str,h_f172);  
      set(h_f172,'String',facet(17,2));        
      
   case 'f173' 
      h_f173 = findobj(gcf,'Tag','f173'); 
      f_str = get(gcbo,'String');   
      facet(17,3) = getFVal(f_str,h_f173);  
      set(h_f173,'String',facet(17,3));    
      
   case 'f174'
      h_f174 = findobj(gcf,'Tag','f174'); 
      f_str = get(gcbo,'String');   
      facet(17,4) = getFVal(f_str,h_f174);  
      set(h_f174,'String',facet(17,4));                  
 	% 5s are ilumination values      
   case 'f175'   
      h_f175 = findobj(gcf,'Tag','f175'); 
      f_str = get(gcbo,'String');   
      facet(17,5) = getIVal(f_str,h_f175);  
      set(h_f175,'String',facet(17,5));        
  % 6s are Resistivity values        
   case 'f176'   
      h_f176 = findobj(gcf,'Tag','f176'); 
      f_str = get(gcbo,'String');   
      facet(17,6) = getRVal(f_str,h_f176);  
      set(h_f176,'String',facet(17,6));        
      
   case 'f182' 
      h_f182 = findobj(gcf,'Tag','f182'); 
      f_str = get(gcbo,'String');   
      facet(18,2) = getFVal(f_str,h_f182);  
      set(h_f182,'String',facet(18,2));        
      
   case 'f183' 
      h_f183 = findobj(gcf,'Tag','f183'); 
      f_str = get(gcbo,'String');   
      facet(18,3) = getFVal(f_str,h_f183);  
      set(h_f183,'String',facet(18,3));    
      
   case 'f184'
      h_f184 = findobj(gcf,'Tag','f184'); 
      f_str = get(gcbo,'String');   
      facet(18,4) = getFVal(f_str,h_f184);  
      set(h_f184,'String',facet(18,4));                  
 	% 5s are ilumination values      
   case 'f185'   
      h_f185 = findobj(gcf,'Tag','f185'); 
      f_str = get(gcbo,'String');   
      facet(18,5) = getIVal(f_str,h_f185);  
      set(h_f185,'String',facet(18,5));        
  % 6s are Resistivity values        
   case 'f186'   
      h_f186 = findobj(gcf,'Tag','f186'); 
      f_str = get(gcbo,'String');   
      facet(18,6) = getRVal(f_str,h_f186);  
      set(h_f186,'String',facet(18,6));        
      
   case 'f192' 
      h_f192 = findobj(gcf,'Tag','f192'); 
      f_str = get(gcbo,'String');   
      facet(19,2) = getFVal(f_str,h_f192);  
      set(h_f192,'String',facet(19,2));        
      
   case 'f193' 
      h_f193 = findobj(gcf,'Tag','f193'); 
      f_str = get(gcbo,'String');   
      facet(19,3) = getFVal(f_str,h_f193);  
      set(h_f193,'String',facet(19,3));    
      
   case 'f194'
      h_f194 = findobj(gcf,'Tag','f194'); 
      f_str = get(gcbo,'String');   
      facet(19,4) = getFVal(f_str,h_f194);  
      set(h_f194,'String',facet(19,4));                  
 	% 5s are ilumination values      
   case 'f195'   
      h_f195 = findobj(gcf,'Tag','f195'); 
      f_str = get(gcbo,'String');   
      facet(19,5) = getIVal(f_str,h_f195);  
      set(h_f195,'String',facet(19,5));        
  % 6s are Resistivity values        
   case 'f196'   
      h_f196 = findobj(gcf,'Tag','f196'); 
      f_str = get(gcbo,'String');   
      facet(19,6) = getRVal(f_str,h_f196);  
      set(h_f196,'String',facet(19,6));        
    
   case 'f202' 
      h_f202 = findobj(gcf,'Tag','f202'); 
      f_str = get(gcbo,'String');   
      facet(20,2) = getFVal(f_str,h_f202);  
      set(h_f202,'String',facet(20,2));        
      
   case 'f203' 
      h_f203 = findobj(gcf,'Tag','f203'); 
      f_str = get(gcbo,'String');   
      facet(20,3) = getFVal(f_str,h_f203);  
      set(h_f203,'String',facet(20,3));    
      
   case 'f204'
      h_f204 = findobj(gcf,'Tag','f204'); 
      f_str = get(gcbo,'String');   
      facet(20,4) = getFVal(f_str,h_f204);  
      set(h_f204,'String',facet(20,4));                  
 	% 5s are ilumination values      
   case 'f205'   
      h_f205 = findobj(gcf,'Tag','f205'); 
      f_str = get(gcbo,'String');   
      facet(20,5) = getIVal(f_str,h_f205);  
      set(h_f205,'String',facet(20,5));                  
   % 6s are Resistivity values        
   case 'f206'   
      h_f206 = findobj(gcf,'Tag','f206'); 
      f_str = get(gcbo,'String');   
      facet(20,6) = getRVal(f_str,h_f206);  
      set(h_f206,'String',facet(20,6));        
      
   case 'f212' 
      h_f212 = findobj(gcf,'Tag','f212'); 
      f_str = get(gcbo,'String');   
      facet(21,2) = getFVal(f_str,h_f212);  
      set(h_f212,'String',facet(21,2));        
      
   case 'f213' 
      h_f213 = findobj(gcf,'Tag','f213'); 
      f_str = get(gcbo,'String');   
      facet(21,3) = getFVal(f_str,h_f213);  
      set(h_f213,'String',facet(21,3));    
      
   case 'f214'
      h_f214 = findobj(gcf,'Tag','f214'); 
      f_str = get(gcbo,'String');   
      facet(21,4) = getFVal(f_str,h_f214);  
      set(h_f214,'String',facet(21,4));                  
 	% 5s are ilumination values      
   case 'f215'   
      h_f215 = findobj(gcf,'Tag','f215'); 
      f_str = get(gcbo,'String');   
      facet(21,5) = getIVal(f_str,h_f215);  
      set(h_f215,'String',facet(21,5));                  
   % 6s are Resistivity values        
   case 'f216'   
      h_f216 = findobj(gcf,'Tag','f216'); 
      f_str = get(gcbo,'String');   
      facet(21,6) = getRVal(f_str,h_f216);  
      set(h_f216,'String',facet(21,6));        
      
   case 'f222' 
      h_f222 = findobj(gcf,'Tag','f222'); 
      f_str = get(gcbo,'String');   
      facet(22,2) = getFVal(f_str,h_f222);  
      set(h_f222,'String',facet(22,2));        
      
   case 'f223' 
      h_f223 = findobj(gcf,'Tag','f223'); 
      f_str = get(gcbo,'String');   
      facet(22,3) = getFVal(f_str,h_f223);  
      set(h_f223,'String',facet(22,3));    
      
   case 'f224'
      h_f224 = findobj(gcf,'Tag','f224'); 
      f_str = get(gcbo,'String');   
      facet(22,4) = getFVal(f_str,h_f224);  
      set(h_f224,'String',facet(22,4));                  
 	% 5s are ilumination values      
   case 'f225'   
      h_f225 = findobj(gcf,'Tag','f225'); 
      f_str = get(gcbo,'String');   
      facet(22,5) = getIVal(f_str,h_f225);  
      set(h_f225,'String',facet(22,5));                  
   % 6s are Resistivity values        
   case 'f226'   
      h_f226 = findobj(gcf,'Tag','f226'); 
      f_str = get(gcbo,'String');   
      facet(22,6) = getRVal(f_str,h_f226);  
      set(h_f226,'String',facet(22,6));        
      
   case 'f232' 
      h_f232 = findobj(gcf,'Tag','f232'); 
      f_str = get(gcbo,'String');   
      facet(23,2) = getFVal(f_str,h_f232);  
      set(h_f232,'String',facet(23,2));        
      
   case 'f233' 
      h_f233 = findobj(gcf,'Tag','f233'); 
      f_str = get(gcbo,'String');   
      facet(23,3) = getFVal(f_str,h_f233);  
      set(h_f233,'String',facet(23,3));    
      
   case 'f234'
      h_f234 = findobj(gcf,'Tag','f234'); 
      f_str = get(gcbo,'String');   
      facet(23,4) = getFVal(f_str,h_f234);  
      set(h_f234,'String',facet(23,4));                  
 	% 5s are ilumination values      
   case 'f235'   
      h_f235 = findobj(gcf,'Tag','f235'); 
      f_str = get(gcbo,'String');   
      facet(23,5) = getIVal(f_str,h_f235);  
      set(h_f235,'String',facet(23,5));                  
   % 6s are Resistivity values        
   case 'f236'   
      h_f236 = findobj(gcf,'Tag','f236'); 
      f_str = get(gcbo,'String');   
      facet(23,6) = getRVal(f_str,h_f236);  
      set(h_f236,'String',facet(23,6));        
      
   case 'f242' 
      h_f242 = findobj(gcf,'Tag','f242'); 
      f_str = get(gcbo,'String');   
      facet(24,2) = getFVal(f_str,h_f242);  
      set(h_f242,'String',facet(24,2));        
      
   case 'f243' 
      h_f243 = findobj(gcf,'Tag','f243'); 
      f_str = get(gcbo,'String');   
      facet(24,3) = getFVal(f_str,h_f243);  
      set(h_f243,'String',facet(24,3));    
      
   case 'f244'
      h_f244 = findobj(gcf,'Tag','f244'); 
      f_str = get(gcbo,'String');   
      facet(24,4) = getFVal(f_str,h_f244);  
      set(h_f244,'String',facet(24,4));                  
 	% 5s are ilumination values      
   case 'f245'   
      h_f245 = findobj(gcf,'Tag','f245'); 
      f_str = get(gcbo,'String');   
      facet(24,5) = getIVal(f_str,h_f245);  
      set(h_f245,'String',facet(24,5));                  
   % 6s are Resistivity values        
   case 'f246'   
      h_f246 = findobj(gcf,'Tag','f246'); 
      f_str = get(gcbo,'String');   
      facet(24,6) = getRVal(f_str,h_f246);  
      set(h_f246,'String',facet(24,6));        
      
   case 'f252' 
      h_f252 = findobj(gcf,'Tag','f252'); 
      f_str = get(gcbo,'String');   
      facet(25,2) = getFVal(f_str,h_f252);  
      set(h_f252,'String',facet(25,2));        
      
   case 'f253' 
      h_f253 = findobj(gcf,'Tag','f253'); 
      f_str = get(gcbo,'String');   
      facet(25,3) = getFVal(f_str,h_f253);  
      set(h_f253,'String',facet(25,3));    
      
   case 'f254'
      h_f254 = findobj(gcf,'Tag','f254'); 
      f_str = get(gcbo,'String');   
      facet(25,4) = getFVal(f_str,h_f254);  
      set(h_f254,'String',facet(25,4));                  
 	% 5s are ilumination values      
   case 'f255'   
      h_f255 = findobj(gcf,'Tag','f255'); 
      f_str = get(gcbo,'String');   
      facet(25,5) = getIVal(f_str,h_f255);  
      set(h_f255,'String',facet(25,5));                  
   % 6s are Resistivity values        
   case 'f256'   
      h_f256 = findobj(gcf,'Tag','f256'); 
      f_str = get(gcbo,'String');   
      facet(25,6) = getRVal(f_str,h_f256);  
      set(h_f256,'String',facet(25,6));        
      
   case 'f262' 
      h_f262 = findobj(gcf,'Tag','f262'); 
      f_str = get(gcbo,'String');   
      facet(26,2) = getFVal(f_str,h_f262);  
      set(h_f262,'String',facet(26,2));        
      
   case 'f263' 
      h_f263 = findobj(gcf,'Tag','f263'); 
      f_str = get(gcbo,'String');   
      facet(26,3) = getFVal(f_str,h_f263);  
      set(h_f263,'String',facet(26,3));    
      
   case 'f264'
      h_f264 = findobj(gcf,'Tag','f264'); 
      f_str = get(gcbo,'String');   
      facet(26,4) = getFVal(f_str,h_f264);  
      set(h_f264,'String',facet(26,4));                  
 	% 5s are ilumination values      
   case 'f265'   
      h_f265 = findobj(gcf,'Tag','f265'); 
      f_str = get(gcbo,'String');   
      facet(26,5) = getIVal(f_str,h_f265);  
      set(h_f265,'String',facet(26,5));                  
   % 6s are Resistivity values        
   case 'f266'   
      h_f266 = findobj(gcf,'Tag','f266'); 
      f_str = get(gcbo,'String');   
      facet(26,6) = getRVal(f_str,h_f266);  
      set(h_f266,'String',facet(26,6));        
   
   case 'f272' 
      h_f272 = findobj(gcf,'Tag','f272'); 
      f_str = get(gcbo,'String');   
      facet(27,2) = getFVal(f_str,h_f272);  
      set(h_f272,'String',facet(27,2));        
      
   case 'f273' 
      h_f273 = findobj(gcf,'Tag','f273'); 
      f_str = get(gcbo,'String');   
      facet(27,3) = getFVal(f_str,h_f273);  
      set(h_f273,'String',facet(27,3));    
      
   case 'f274'
      h_f274 = findobj(gcf,'Tag','f274'); 
      f_str = get(gcbo,'String');   
      facet(27,4) = getFVal(f_str,h_f274);  
      set(h_f274,'String',facet(27,4));                  
 	% 5s are ilumination values      
   case 'f275'   
      h_f275 = findobj(gcf,'Tag','f275'); 
      f_str = get(gcbo,'String');   
      facet(27,5) = getIVal(f_str,h_f275);  
      set(h_f275,'String',facet(27,5));                  
   % 6s are Resistivity values        
   case 'f276'   
      h_f276 = findobj(gcf,'Tag','f276'); 
      f_str = get(gcbo,'String');   
      facet(27,6) = getRVal(f_str,h_f276);  
      set(h_f276,'String',facet(27,6));        
      
   case 'f282' 
      h_f282 = findobj(gcf,'Tag','f282'); 
      f_str = get(gcbo,'String');   
      facet(28,2) = getFVal(f_str,h_f282);  
      set(h_f282,'String',facet(28,2));        
      
   case 'f283' 
      h_f283 = findobj(gcf,'Tag','f283'); 
      f_str = get(gcbo,'String');   
      facet(28,3) = getFVal(f_str,h_f283);  
      set(h_f283,'String',facet(28,3));    
      
   case 'f284'
      h_f284 = findobj(gcf,'Tag','f284'); 
      f_str = get(gcbo,'String');   
      facet(28,4) = getFVal(f_str,h_f284);  
      set(h_f284,'String',facet(28,4));                  
 	% 5s are ilumination values      
   case 'f285'   
      h_f285 = findobj(gcf,'Tag','f285'); 
      f_str = get(gcbo,'String');   
      facet(28,5) = getIVal(f_str,h_f285);  
      set(h_f285,'String',facet(28,5));                  
   % 6s are Resistivity values        
   case 'f286'   
      h_f286 = findobj(gcf,'Tag','f286'); 
      f_str = get(gcbo,'String');   
      facet(28,6) = getRVal(f_str,h_f286);  
      set(h_f286,'String',facet(28,6));        
      
   case 'f292' 
      h_f292 = findobj(gcf,'Tag','f292'); 
      f_str = get(gcbo,'String');   
      facet(29,2) = getFVal(f_str,h_f292);  
      set(h_f292,'String',facet(29,2));        
      
   case 'f293' 
      h_f293 = findobj(gcf,'Tag','f293'); 
      f_str = get(gcbo,'String');   
      facet(29,3) = getFVal(f_str,h_f293);  
      set(h_f293,'String',facet(29,3));    
      
   case 'f294'
      h_f294 = findobj(gcf,'Tag','f294'); 
      f_str = get(gcbo,'String');   
      facet(29,4) = getFVal(f_str,h_f294);  
      set(h_f294,'String',facet(29,4));                  
 	% 5s are ilumination values      
   case 'f295'   
      h_f295 = findobj(gcf,'Tag','f295'); 
      f_str = get(gcbo,'String');   
      facet(29,5) = getIVal(f_str,h_f295);  
      set(h_f295,'String',facet(29,5));                  
   % 6s are Resistivity values        
   case 'f296'   
      h_f296 = findobj(gcf,'Tag','f296'); 
      f_str = get(gcbo,'String');   
      facet(29,6) = getRVal(f_str,h_f296);  
      set(h_f296,'String',facet(29,6));        
      
   case 'f302' 
      h_f302 = findobj(gcf,'Tag','f302'); 
      f_str = get(gcbo,'String');   
      facet(30,2) = getFVal(f_str,h_f302);  
      set(h_f302,'String',facet(30,2));        
      
   case 'f303' 
      h_f303 = findobj(gcf,'Tag','f303'); 
      f_str = get(gcbo,'String');   
      facet(30,3) = getFVal(f_str,h_f303);  
      set(h_f303,'String',facet(30,3));    
      
   case 'f304'
      h_f304 = findobj(gcf,'Tag','f304'); 
      f_str = get(gcbo,'String');   
      facet(30,4) = getFVal(f_str,h_f304);  
      set(h_f304,'String',facet(30,4));                  
 	% 5s are ilumination values      
   case 'f305'   
      h_f305 = findobj(gcf,'Tag','f305'); 
      f_str = get(gcbo,'String');   
      facet(30,5) = getIVal(f_str,h_f305);  
      set(h_f305,'String',facet(30,5));                  
   % 6s are Resistivity values        
   case 'f306'   
      h_f306 = findobj(gcf,'Tag','f306'); 
      f_str = get(gcbo,'String');   
      facet(30,6) = getRVal(f_str,h_f306);  
      set(h_f306,'String',facet(30,6));                    
      
   case 'f312' 
      h_f312 = findobj(gcf,'Tag','f312'); 
      f_str = get(gcbo,'String');   
      facet(31,2) = getFVal(f_str,h_f312);  
      set(h_f312,'String',facet(31,2));        
      
   case 'f313' 
      h_f313 = findobj(gcf,'Tag','f313'); 
      f_str = get(gcbo,'String');   
      facet(31,3) = getFVal(f_str,h_f313);  
      set(h_f313,'String',facet(31,3));    
      
   case 'f314'
      h_f314 = findobj(gcf,'Tag','f314'); 
      f_str = get(gcbo,'String');   
      facet(31,4) = getFVal(f_str,h_f314);  
      set(h_f314,'String',facet(31,4));                  
 	% 5s are ilumination values      
   case 'f315'   
      h_f315 = findobj(gcf,'Tag','f315'); 
      f_str = get(gcbo,'String');   
      facet(31,5) = getIVal(f_str,h_f315);  
      set(h_f315,'String',facet(31,5));                  
   % 6s are Resistivity values        
   case 'f316'   
      h_f316 = findobj(gcf,'Tag','f316'); 
      f_str = get(gcbo,'String');   
      facet(31,6) = getRVal(f_str,h_f316);  
      set(h_f316,'String',facet(31,6));        
      
   case 'f322' 
      h_f322 = findobj(gcf,'Tag','f322'); 
      f_str = get(gcbo,'String');   
      facet(32,2) = getFVal(f_str,h_f322);  
      set(h_f322,'String',facet(32,2));        
      
   case 'f323' 
      h_f323 = findobj(gcf,'Tag','f323'); 
      f_str = get(gcbo,'String');   
      facet(32,3) = getFVal(f_str,h_f323);  
      set(h_f323,'String',facet(32,3));    
      
   case 'f324'
      h_f324 = findobj(gcf,'Tag','f324'); 
      f_str = get(gcbo,'String');   
      facet(32,4) = getFVal(f_str,h_f324);  
      set(h_f324,'String',facet(32,4));                  
 	% 5s are ilumination values      
   case 'f325'   
      h_f325 = findobj(gcf,'Tag','f325'); 
      f_str = get(gcbo,'String');   
      facet(32,5) = getIVal(f_str,h_f325);  
      set(h_f325,'String',facet(32,5));                  
   % 6s are Resistivity values        
   case 'f326'   
      h_f326 = findobj(gcf,'Tag','f326'); 
      f_str = get(gcbo,'String');   
      facet(32,6) = getRVal(f_str,h_f326);  
      set(h_f326,'String',facet(32,6));        
      
   case 'f332' 
      h_f332 = findobj(gcf,'Tag','f332'); 
      f_str = get(gcbo,'String');   
      facet(33,2) = getFVal(f_str,h_f332);  
      set(h_f332,'String',facet(33,2));        
      
   case 'f333' 
      h_f333 = findobj(gcf,'Tag','f333'); 
      f_str = get(gcbo,'String');   
      facet(33,3) = getFVal(f_str,h_f333);  
      set(h_f333,'String',facet(33,3));    
      
   case 'f334'
      h_f334 = findobj(gcf,'Tag','f334'); 
      f_str = get(gcbo,'String');   
      facet(33,4) = getFVal(f_str,h_f334);  
      set(h_f334,'String',facet(33,4));                  
 	% 5s are ilumination values      
   case 'f335'   
      h_f335 = findobj(gcf,'Tag','f335'); 
      f_str = get(gcbo,'String');   
      facet(33,5) = getIVal(f_str,h_f335);  
      set(h_f335,'String',facet(33,5));                  
   % 6s are Resistivity values        
   case 'f336'   
      h_f336 = findobj(gcf,'Tag','f336'); 
      f_str = get(gcbo,'String');   
      facet(33,6) = getRVal(f_str,h_f336);  
      set(h_f336,'String',facet(33,6));        
      
   case 'f342' 
      h_f342 = findobj(gcf,'Tag','f342'); 
      f_str = get(gcbo,'String');   
      facet(34,2) = getFVal(f_str,h_f342);  
      set(h_f342,'String',facet(34,2));        
      
   case 'f343' 
      h_f343 = findobj(gcf,'Tag','f343'); 
      f_str = get(gcbo,'String');   
      facet(34,3) = getFVal(f_str,h_f343);  
      set(h_f343,'String',facet(34,3));    
      
   case 'f344'
      h_f344 = findobj(gcf,'Tag','f344'); 
      f_str = get(gcbo,'String');   
      facet(34,4) = getFVal(f_str,h_f344);  
      set(h_f344,'String',facet(34,4));                  
 	% 5s are ilumination values      
   case 'f345'   
      h_f345 = findobj(gcf,'Tag','f345'); 
      f_str = get(gcbo,'String');   
      facet(34,5) = getIVal(f_str,h_f345);  
      set(h_f345,'String',facet(34,5));                  
   % 6s are Resistivity values        
   case 'f346'   
      h_f346 = findobj(gcf,'Tag','f346'); 
      f_str = get(gcbo,'String');   
      facet(34,6) = getRVal(f_str,h_f346);  
      set(h_f346,'String',facet(34,6));        
     
   case 'f352' 
      h_f352 = findobj(gcf,'Tag','f352'); 
      f_str = get(gcbo,'String');   
      facet(35,2) = getFVal(f_str,h_f352);  
      set(h_f352,'String',facet(35,2));        
      
   case 'f353' 
      h_f353 = findobj(gcf,'Tag','f353'); 
      f_str = get(gcbo,'String');   
      facet(35,3) = getFVal(f_str,h_f353);  
      set(h_f353,'String',facet(35,3));    
      
   case 'f354'
      h_f354 = findobj(gcf,'Tag','f354'); 
      f_str = get(gcbo,'String');   
      facet(35,4) = getFVal(f_str,h_f354);  
      set(h_f354,'String',facet(35,4));                  
 	% 5s are ilumination values      
   case 'f355'   
      h_f355 = findobj(gcf,'Tag','f355'); 
      f_str = get(gcbo,'String');   
      facet(35,5) = getIVal(f_str,h_f355);  
      set(h_f355,'String',facet(35,5));                  
   % 6s are Resistivity values        
   case 'f356'   
      h_f356 = findobj(gcf,'Tag','f356'); 
      f_str = get(gcbo,'String');   
      facet(35,6) = getRVal(f_str,h_f356);  
      set(h_f356,'String',facet(35,6));                    
      
   case 'f362' 
      h_f362 = findobj(gcf,'Tag','f362'); 
      f_str = get(gcbo,'String');   
      facet(36,2) = getFVal(f_str,h_f362);  
      set(h_f362,'String',facet(36,2));        
      
   case 'f363' 
      h_f363 = findobj(gcf,'Tag','f363'); 
      f_str = get(gcbo,'String');   
      facet(36,3) = getFVal(f_str,h_f363);  
      set(h_f363,'String',facet(36,3));    
      
   case 'f364'
      h_f364 = findobj(gcf,'Tag','f364'); 
      f_str = get(gcbo,'String');   
      facet(36,4) = getFVal(f_str,h_f364);  
      set(h_f364,'String',facet(36,4));                  
 	% 5s are ilumination values      
   case 'f365'   
      h_f365 = findobj(gcf,'Tag','f365'); 
      f_str = get(gcbo,'String');   
      facet(36,5) = getIVal(f_str,h_f365);  
      set(h_f365,'String',facet(36,5));                  
   % 6s are Resistivity values        
   case 'f366'   
      h_f366 = findobj(gcf,'Tag','f366'); 
      f_str = get(gcbo,'String');   
      facet(36,6) = getRVal(f_str,h_f366);  
      set(h_f366,'String',facet(36,6));        
      
   case 'f372' 
      h_f372 = findobj(gcf,'Tag','f372'); 
      f_str = get(gcbo,'String');   
      facet(37,2) = getFVal(f_str,h_f372);  
      set(h_f372,'String',facet(37,2));        
      
   case 'f373' 
      h_f373 = findobj(gcf,'Tag','f373'); 
      f_str = get(gcbo,'String');   
      facet(37,3) = getFVal(f_str,h_f373);  
      set(h_f373,'String',facet(37,3));    
      
   case 'f374'
      h_f374 = findobj(gcf,'Tag','f374'); 
      f_str = get(gcbo,'String');   
      facet(37,4) = getFVal(f_str,h_f374);  
      set(h_f374,'String',facet(37,4));                  
 	% 5s are ilumination values      
   case 'f375'   
      h_f375 = findobj(gcf,'Tag','f375'); 
      f_str = get(gcbo,'String');   
      facet(37,5) = getIVal(f_str,h_f375);  
      set(h_f375,'String',facet(37,5));                  
   % 6s are Resistivity values        
   case 'f376'   
      h_f376 = findobj(gcf,'Tag','f376'); 
      f_str = get(gcbo,'String');   
      facet(37,6) = getRVal(f_str,h_f376);  
      set(h_f376,'String',facet(37,6));        
      
   case 'f382' 
      h_f382 = findobj(gcf,'Tag','f382'); 
      f_str = get(gcbo,'String');   
      facet(38,2) = getFVal(f_str,h_f382);  
      set(h_f382,'String',facet(38,2));        
      
   case 'f383' 
      h_f383 = findobj(gcf,'Tag','f383'); 
      f_str = get(gcbo,'String');   
      facet(38,3) = getFVal(f_str,h_f383);  
      set(h_f383,'String',facet(38,3));    
      
   case 'f384'
      h_f384 = findobj(gcf,'Tag','f384'); 
      f_str = get(gcbo,'String');   
      facet(38,4) = getFVal(f_str,h_f384);  
      set(h_f384,'String',facet(38,4));                  
 	% 5s are ilumination values      
   case 'f385'   
      h_f365 = findobj(gcf,'Tag','f385'); 
      f_str = get(gcbo,'String');   
      facet(38,5) = getIVal(f_str,h_f385);  
      set(h_f385,'String',facet(38,5));                  
   % 6s are Resistivity values        
   case 'f386'   
      h_f386 = findobj(gcf,'Tag','f386'); 
      f_str = get(gcbo,'String');   
      facet(38,6) = getRVal(f_str,h_f386);  
      set(h_f386,'String',facet(38,6));        
   
   case 'f392' 
      h_f392 = findobj(gcf,'Tag','f392'); 
      f_str = get(gcbo,'String');   
      facet(39,2) = getFVal(f_str,h_f392);  
      set(h_f392,'String',facet(39,2));        
      
   case 'f393' 
      h_f393 = findobj(gcf,'Tag','f393'); 
      f_str = get(gcbo,'String');   
      facet(39,3) = getFVal(f_str,h_f393);  
      set(h_f393,'String',facet(39,3));    
      
   case 'f394'
      h_f394 = findobj(gcf,'Tag','f394'); 
      f_str = get(gcbo,'String');   
      facet(39,4) = getFVal(f_str,h_f394);  
      set(h_f394,'String',facet(39,4));                  
 	% 5s are ilumination values      
   case 'f395'   
      h_f395 = findobj(gcf,'Tag','f395'); 
      f_str = get(gcbo,'String');   
      facet(39,5) = getIVal(f_str,h_f395);  
      set(h_f395,'String',facet(39,5));                  
   % 6s are Resistivity values        
   case 'f396'   
      h_f396 = findobj(gcf,'Tag','f396'); 
      f_str = get(gcbo,'String');   
      facet(39,6) = getRVal(f_str,h_f396);  
      set(h_f396,'String',facet(39,6));        
      
   case 'f402' 
      h_f402 = findobj(gcf,'Tag','f402'); 
      f_str = get(gcbo,'String');   
      facet(40,2) = getFVal(f_str,h_f402);  
      set(h_f402,'String',facet(40,2));        
      
   case 'f403' 
      h_f403 = findobj(gcf,'Tag','f403'); 
      f_str = get(gcbo,'String');   
      facet(40,3) = getFVal(f_str,h_f403);  
      set(h_f403,'String',facet(40,3));    
      
   case 'f404'
      h_f404 = findobj(gcf,'Tag','f404'); 
      f_str = get(gcbo,'String');   
      facet(40,4) = getFVal(f_str,h_f404);  
      set(h_f404,'String',facet(40,4));                  
 	% 5s are ilumination values      
   case 'f405'   
      h_f405 = findobj(gcf,'Tag','f405'); 
      f_str = get(gcbo,'String');   
      facet(40,5) = getIVal(f_str,h_f405);  
      set(h_f405,'String',facet(40,5));                  
   % 6s are Resistivity values        
   case 'f406'   
      h_f406 = findobj(gcf,'Tag','f406'); 
      f_str = get(gcbo,'String');   
      facet(40,6) = getRVal(f_str,h_f406);  
      set(h_f406,'String',facet(40,6));                            
      
end % switch
   
   
% validate number of facets/triangles entered    
function o_ntria = getNFacet(ntria_str)     
  	temp = str2num(ntria_str); 					 
      
   if isempty(temp) | floor(temp) < 1  	
      errordlg('Please check number of facets entered.','Number of Facets Status', 'error');
      temp = 1;  %  default number of facets   
      set(findobj(gcf,'Tag','NFacet'),'String',temp);
   elseif (ntria_str == 'i') | (ntria_str == 'j')          
      errordlg('Please check number of facets entered.','Number of Facets Status', 'error');
      temp = 1;     
      set(findobj(gcf,'Tag','NFacet'),'String',temp);
   elseif (floor(temp) > 40)
		errordlg('Design can handle up to 40 facets only!','Maximum Number of Facets','warn');         
	   temp = 1;
      set(findobj(gcf,'Tag','NFacet'),'String',temp);
   end 
	o_ntria = floor(temp);      
      
function h_fc = createFarray(nfc)
	% x-positions of text boxes wrt figure in left frame
   tx1 = 0.04; tx2 = 0.118; tx3 = 0.194; 
   tx4 = 0.271; tx5 = 0.35; tx6 = 0.423;    
   
   % baseline y-position of text boxes wrt figure
	ty = 0.856;  

	% x-y dimensions of facet number box
	wx = 0.0625;   wy = 0.034;    

	% x-positions of text boxes wrt figure in right frame
   fx1 = 0.52; fx2 = 0.595; fx3 = 0.675; 
   fx4 = 0.755; fx5 = 0.832; fx6 = 0.91;
  
	if nfc <=20
   	fa1 = farray1(nfc, tx1, tx2, tx3, tx4, tx5, tx6, ty, wx, wy);   
		h_fc = fa1;      
	elseif nfc <= 40
   	fa2 = farray2(nfc, tx1, tx2, tx3, tx4, tx5, tx6, ty, wx, wy,...
      	  			  fx1, fx2, fx3, fx4, fx5, fx6);
	   h_fc = fa2;         
   end  % if
           	    
function fa1 = farray1(nfc, tx1, tx2, tx3, tx4, tx5, tx6, ty, wx, wy)
	for i = 1:nfc
      fa1(i,1) = uicontrol('Units', 'normalized', ...
     	   'Position',[tx1 (ty-(i-1)*(0.04)) wx wy], ...
        	'Backg',[1 1 1], ...
	      'Fore', [0 0 0], ...
	      'Style','edit', ...
         'Fonts', 0.5, ...    
         'Callb',['fcets ','f',num2str(i),num2str(1)], ...  
			'Tag',['f',num2str(i),'1']);
      set(fa1(i,1),'String',num2str(i),'enable','off');         
	   fa1(i,2) = uicontrol('Units', 'normalized', ...
   	   'Position',[tx2 (ty-(i-1)*(0.04)) wx wy], ...
      	'Style','edit', ...
         'Backg',[1 1 1], ...
	      'Fore', [0 0 0], ...
         'String',1, ...
      	'Fonts', 0.5, ...
         'Callb',['fcets ','f',num2str(i),num2str(2)], ...  
			'Tag',['f',num2str(i),'2']);
      fa1(i,3) = uicontrol('Units', 'normalized', ...
   	   'Position',[tx3 (ty-(i-1)*(0.04)) wx wy], ...
      	'Style','edit', ...
         'Backg',[1 1 1], ...
         'Fore', [0 0 0], ...
         'String',1, ...
   	   'Fonts', 0.5, ...
         'Callb',['fcets ','f',num2str(i),num2str(3)], ...  
			'Tag',['f',num2str(i),'3']);
      fa1(i,4) = uicontrol('Units', 'normalized', ...
  	      'Position',[tx4 (ty-(i-1)*(0.04)) wx wy], ...
     	   'Style','edit', ...
        	'Backg',[1 1 1], ...
         'Fore', [0 0 0], ...
         'String',1, ...         
      	'Fonts', 0.5, ...
         'Callb',['fcets ','f',num2str(i),num2str(4)], ...  
			'Tag',['f',num2str(i),'4']);
      fa1(i,5) = uicontrol('Units', 'normalized', ...
  	      'Position',[tx5 (ty-(i-1)*(0.04)) wx wy], ...
     	   'Style','edit', ...
        	'Backg',[1 1 1], ...
         'Fore', [0 0 0], ...
         'Fonts', 0.5, ...
         'String',1, ...         
         'Callb',['fcets ','f',num2str(i),num2str(5)], ...  
			'Tag',['f',num2str(i),'5']);
      fa1(i,6) = uicontrol('Units', 'normalized', ...
  	      'Position',[tx6 (ty-(i-1)*(0.04)) wx wy], ...
     	   'Style','edit', ...
        	'Backg',[1 1 1], ...
         'Fore', [0 0 0], ...
         'Fonts', 0.5, ...
         'String',0, ...         
         'Callb',['fcets ','f',num2str(i),num2str(6)], ...  
			'Tag',['f',num2str(i),'6']);
   end % for

function fa2 = farray2(nfc, tx1, tx2, tx3, tx4, tx5, tx6, ty, wx, wy, ...
                     fx1, fx2, fx3, fx4, fx5, fx6);

   fa1 = farray1(20, tx1, tx2, tx3, tx4, tx5, tx6, ty, wx, wy);
   fa2 = fa1;
	for i = 21:nfc
  	   fa2(i,1) = uicontrol('Units', 'normalized', ...
     	   'Position',[fx1 (ty-(i-21)*(0.04)) wx wy], ...
        	'Backg',[1 1 1], ...
         'Fore', [0 0 0], ...
         'Style','edit', ...
  	      'Fonts', 0.5, ...
         'Callb',['fcets ','f',num2str(i),num2str(1)], ...  
			'Tag',['f',num2str(i),'1']);
      set(fa2(i,1),'String',num2str(i),'enable','off');                           
      fa2(i,2) = uicontrol('Units', 'normalized', ...
  	      'Position',[fx2 (ty-(i-21)*(0.04)) wx wy], ...
     	   'Style','edit', ...
        	'Backg',[1 1 1], ...
         'Fore', [0 0 0], ...
         'String',1, ...
      	'Fonts', 0.5, ...
         'Callb',['fcets ','f',num2str(i),num2str(2)], ...  
			'Tag',['f',num2str(i),'2']);
      fa2(i,3) = uicontrol('Units', 'normalized', ...
  	      'Position',[fx3 (ty-(i-21)*(0.04)) wx wy], ...
         'Style','edit', ...
        	'Backg',[1 1 1], ...
	      'Fore', [0 0 0], ...
         'String',1, ...         
	      'Fonts', 0.5, ...
         'Callb',['fcets ','f',num2str(i),num2str(3)], ...  
			'Tag',['f',num2str(i),'3']);
      fa2(i,4) = uicontrol('Units', 'normalized', ...
   	   'Position',[fx4 (ty-(i-21)*(0.04)) wx wy], ...
         'Style','edit', ...
        	'Backg',[1 1 1], ...
	      'Fore', [0 0 0], ...
         'String',1, ...         
      	'Fonts', 0.5, ...
         'Callb',['fcets ','f',num2str(i),num2str(4)], ...  
			'Tag',['f',num2str(i),'4']);
      fa2(i,5) = uicontrol('Units', 'normalized', ...
   	   'Position',[fx5 (ty-(i-21)*(0.04)) wx wy], ...
         'Style','edit', ...
        	'Backg',[1 1 1], ...
	      'Fore', [0 0 0], ...
         'String',1, ...         
      	'Fonts', 0.5, ...
         'Callb',['fcets ','f',num2str(i),num2str(5)], ...  
			'Tag',['f',num2str(i),'5']);
		fa2(i,6) = uicontrol('Units', 'normalized', ...
   	   'Position',[fx6 (ty-(i-21)*(0.04)) wx wy], ...
         'Style','edit', ...
        	'Backg',[1 1 1], ...
	      'Fore', [0 0 0], ...
         'String',0, ...         
      	'Fonts', 0.5, ...
         'Callb',['fcets ','f',num2str(i),num2str(6)], ...  
			'Tag',['f',num2str(i),'6']);
   end % for                                  
         
% validate uniform resistivity value entered         
function o_uRs = getuRs(uRs_str)     

	temp = str2num(uRs_str); 					 
   if isempty(temp) | (temp < 0)   
     	errordlg('Please enter resistivity value normalized to 377 ohms.','Uniform Resistivity Status', 'error');
      temp = 0;  		%  default for a PEC    
   elseif (temp == 'i') | (temp == 'j')
     	errordlg('Please enter resistivity value normalized to 377 ohms.','Uniform Resistivity Status', 'error');
      temp = 0;  		%  default for a PEC    
   end 
   o_uRs = temp;
  
% validate node number entered for nodes 1, 2,and 3
function o_fval = getFVal(f_str,h_fc)     
   
   ntria = str2num(get(findobj(gcf,'Tag','NFacet'),'String')); 
   temp = str2num(f_str); 			
	h_figs = get(0,'children');
	for fig = h_figs'
	  if strcmp(get(fig,'Tag'),'design');
        h_design = fig;
        break;
     end
   end
   nvert = str2num(get(findobj(h_design,'Tag','NVert'),'String'));                    
   
   if (isempty(temp)) | floor(temp) < 1 
      errordlg('Please check node number entered.','Node Status','error');
      temp = 9999; 	% high value            
     	set(h_fc,'String',temp);             
   elseif (f_str == 'i') | (f_str == 'j')
      errordlg('Please check node number entered.','Node Status','error');
      temp = 9999;	% high value
     	set(h_fc,'String',temp);             
   elseif floor(temp) > nvert
      errordlg('Please check node number entered.','Node Status','error');
      temp = 9999;	% high value
     	set(h_fc,'String',temp);             
   end
   o_fval = floor(temp); 

% validate ilumination value entered for each facet/triangle
function o_ival = getIVal(i_str,h_fi)

	temp = str2num(i_str); 			
      
   if (isempty(temp)) | (floor(temp) ~= 0 & floor(temp) ~= 1)
      errordlg('Enter a value of 1 if one side or 0 if both sides will be illuminated.', ...
               'Facet Illumination Status','error');
      temp = 9999;	% high value             
     	set(h_fi,'String',9999);             
   elseif (i_str == 'i') | (i_str == 'j')
      errordlg('Enter a value of 1 if one side or 0 if both sides will be illuminated.', ...
            	'Facet Illuminaiton Status','error');
      temp = 9999;	% high value
     	set(h_fi,'String',9999);             
   end
   o_ival = floor(temp); 

% validate Resistivity value entered for each facet/triangle
function o_rval = getRVal(r_str,h_fr)

	temp = str2num(r_str);

	if isempty(temp) | (floor(temp) < 0)   
      errordlg('Please enter resistivity value normalized to 377 ohms.','Facet Resistivity Status', 'error');      
      temp = 9999;  		%  high value          
      set(h_fr,'String',temp);
   elseif (r_str == 'i') | (r_str == 'j')
     	errordlg('Please enter resistivity value normalized to 377 ohms.','Facet Resistivity Status', 'error');    
      temp = 9999;		% high value         
     	set(h_fr,'String',temp);             
   end
   o_rval = temp;  
  