function fig = model(command_str)
% filename: model.m
% Project: POFACETS
% Description: This function displays the plot of the MODEL Geometry and 
% 		provides functionalities to save and print the file data as well as
%		enhance visualization of the plot.
% Author:  Prof. David C. Jenn and Elmo E. Garrido Jr.
% Date:  07 September 2000
% Place: NPS
%
% 	MODEL GEOMETRY GUI

if nargin == 0
   command_str = 'initialize';
end

% Initialize the GUI
if strcmp(command_str,'initialize')
   h_figs = get(0,'children');
   fig_exists = 0;
   for fig = h_figs'
      fig_exists = strcmp(get(fig,'Tag'),'model');
      if fig_exists
         figure(fig);
         return;
      end
   end
end

% Figure
h0 = figure('Units','normalized', ...
	'Color',[0.8 0.8 0.8], ...
	'MenuBar','none', ...
	'Name','   MODEL GEOMETRY', ...
	'NumberTitle','off', ...
	'PaperPosition',[18 180 576 432], ...
	'PaperUnits','points', ...
	'Position',[0.2002 0.3229 0.5469 0.5885], ...
	'Resize','off', ...
	'Tag','model');
% axis
h1 = axes('Parent',h0, ...
   'Box','on', ...
	'FontU','normalized', ...
	'CameraUpVector',[0 1 0], ...
	'CameraUpVectorMode','manual', ...
   'Color',[1 1 1], ...
   'LinestyleOrder','--', ...
	'FontS',0.033, ...
	'Position',[0.061 0.0619 0.66 0.870], ...
	'Tag','ModelAxis', ...
	'XColor',[0 0 0], ...
	'XTick',[0 0.2 0.4 0.6 0.8 1], ...
	'XTickMode','manual', ...
	'YColor',[0 0 0], ...
	'ZColor',[0 0 0]);
% Frames
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'Position',[0.7554 0.1947 0.2321 0.7058], ...
	'Style','frame', ...
	'Tag','Frame1');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'Position',[0.7661 0.7389 0.2143 0.1482], ...
	'Style','frame', ...
   'Tag','Frame2');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'Position',[0.7661 0.65 0.2143 0.08], ...
	'Style','frame', ...
   'Tag','Frame3');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'Position',[0.7661 0.465 0.2143 0.18], ...
	'Style','frame', ...
   'Tag','Frame4');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'Position',[.7661 0.205 0.214 0.25] , ...
	'Style','frame', ...
	'Tag','Frame5');
% Label Checkboxes  >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'Callb','mod LVerts;', ...
   'FontS',0.7, ...
   'FontN','Arial', ...
   'Position',[0.785 0.8274 0.16 0.0354], ...
	'String','Label Vertices', ...
	'Style','checkbox', ...
	'Tag','LVerts');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'Callb','mod LFaces;', ...
   'FontS',0.7, ...
   'FontN','Arial', ...
	'Position',[0.785 0.7765 0.14 0.0354], ...
	'String','Label Faces', ...
	'Style','checkbox', ...
	'Tag','LFaces');
% Grid Checkbox
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'Callb','mod Grid;', ...
   'FontS',0.7, ...
   'FontN','Arial', ...
	'Position',[0.785 0.67 0.07 0.0354], ...
	'String','Grid', ...
	'Style','checkbox', ...
	'Tag','Grid');
% Print Checkboxes
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...	
   'FontS',0.65, ...
   'FontN','Arial', ...
	'Position',[0.773 0.355 0.20 0.0354], ...
   'String','Coordinates/Facets', ...
   'Value',1, ...
	'Style','checkbox', ...
	'Tag','Pr_file');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'FontS',0.7, ...
   'FontN','Arial', ...
	'Position',[0.773 0.3 0.17 0.0354], ...
   'String','Model Geometry', ...
   'Value',1, ...
	'Style','checkbox', ...
   'Tag','Pr_model');
% Editable Text Boxes
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
   'Backg',[1 1 1 ], ...
   'Callb','mod Azim',...
	'FontS',0.7, ...
   'FontN','Arial', ...
   'Position',[0.888 0.59 0.08 0.04], ...
   'String','-37.5', ...
   'Style','edit',...
   'Tag','Azim');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
   'Backg',[1 1 1], ...
   'Callb','mod Elev',...   
	'FontS',0.7, ...
   'FontN','Arial', ...
	'Position',[0.888 0.539 0.08 0.04], ...	   
	'String','30', ...  
   'Style','edit',...
   'Tag','Elev');
% Text
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
   'Backg',[0.8 0.8 0.8], ...
   'Horiz','left', ...
	'FontS',0.7, ...
   'FontN','Arial', ...
	'Position',[0.78 0.59 0.10 0.0354], ...
   'String','Azim. (deg)', ...
	'Style','text');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
   'Backg',[0.8 0.8 0.8], ...
   'Horiz','left', ...
	'FontS',0.7, ...
   'FontN','Arial', ...
	'Position',[0.78 0.539 0.10 0.0354], ...
   'String','Elev. (deg)', ...  
	'Style','text');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
   'FontS',0.8, ...
   'FontN','Arial', ...
	'FontW','bold', ...
	'Position',[0.8286 0.402 0.07 0.0376], ...
	'String','FILES', ...
	'Style','text', ...
   'Tag','StaticText1');
% Pushbuttons Print, Close, and Help
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
   'Backg',[0.8 0.8 0.8], ...
  	'Callb','mod Viewpoint;', ...
   'FontS',0.6, ...
   'FontN','Arial', ...
	'Position',[0.795 0.478 0.16 0.048], ...
	'String','Set Viewpoint', ...
   'Tag','Zoom');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'Callb','mod Print;', ...
	'FontS',0.5, ...
	'Position',[0.805 0.22 0.125 0.0664], ...
	'String','Print', ...
	'Tag','Print');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'Callb','close(gcbf)', ...
	'FontS',0.5, ...
	'Position',[0.7464 0.0929 0.11 0.0619], ...
	'String','Close', ...
	'Tag','Close');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'Callb','hlpmodel', ...
	'FontS',0.5, ...
	'Position',[0.8750 0.0929 0.11 0.0619], ...
	'String','Help', ...
   'Tag','Help');

% Create Pop-up File Menu 

 mod_F = uimenu(gcf,'Label','File');
  			uimenu(mod_F,'Label','&Save','CallB','mod FileSave');
         uimenu(mod_F,'Label','Save &As...','CallB','mod SaveAs');