function modl(action)
% filename: modl.m  % renamed from mod to avoid confusion with intrinsic function
% Project: POFACETS
% Description: This function implements the functionalities of the
%		MODEL GEOMETRY GUI to enhance user view of the model geometry. 
% Author:  Prof. David C. Jenn and Elmo E. Garrido Jr.
% Date:  07 September 2000 
% Place: NPS

global nvert coord scale
global ntria facet

switch(action)
      
   case 'LVerts' 
      val_LVert  = get(findobj(gcf,'Tag','LVerts'),'Value');
      val_LFacet = get(findobj(gcf,'Tag','LFaces'),'Value');
		PlotModel;
		if val_LVert == 1
         if val_LFacet == 1 	% Label Vertices and Facets
            LabelVertices;
            LabelFacets;           
         else					
				LabelVertices;
         end
      else 
         if val_LFacet == 1	% Label Facets Only
            LabelFacets;             
         end
      end
      
      h_radio = findobj(gcf,'Tag','Grid'); 
      if get(h_radio,'Value') == 1
         grid on;
      else
         grid off;
      end
      
   case 'LFaces'
      val_LFacet = get(findobj(gcf,'Tag','LFaces'),'Value');
      val_LVert  = get(findobj(gcf,'Tag','LVerts'),'Value');
		PlotModel;
		if val_LFacet == 1
         if val_LVert == 1 	% Label Vertices and Facets
            LabelFacets;
            LabelVertices;           
         else					
            LabelFacets;
         end
      else 
         if val_LVert == 1	% Label Facets Only
            LabelVertices;
         end
      end                              
      
      h_radio = findobj(gcf,'Tag','Grid'); 
      if get(h_radio,'Value') == 1
         grid on;
      else
         grid off;
      end

   case 'Grid' 
      h_radio = findobj(gcf,'Tag','Grid'); 
      if get(h_radio,'Value') == 1
         grid on;
      else
         grid off;
      end
                  
   case 'Azim' 
      h_azim = findobj(gcf,'Tag','Azim'); 
      azim_str = get(h_azim,'String'); 
      azim = getAzimuth(azim_str); 
      set(h_azim,'String',num2str(azim));
      
   case 'Elev' 
      h_elev = findobj(gcf,'Tag','Elev'); 
      elev_str = get(h_elev,'String'); 
      elev = getElevation(elev_str); 
      set(h_elev,'String',num2str(elev));      
      
   case 'Viewpoint' 
      azim = str2num(get(findobj(gcf,'Tag','Azim'),'String')); 
      elev = str2num(get(findobj(gcf,'Tag','Elev'),'String')); 
      view([azim elev])      
      
   case 'Print'
      val_PrFile  = get(findobj(gcf,'Tag','Pr_file'), 'Value');
      val_PrModel = get(findobj(gcf,'Tag','Pr_model'),'Value');
      if val_PrFile == 1
         h_figs = get(0,'children');
			for fig = h_figs'
 				if strcmp(get(fig,'Tag'),'design') | strcmp(get(fig,'Tag'),'facets')
               figure(fig);  
               print;
            end
         end
      end
      
      if val_PrModel == 1
      	h_figs = get(0,'children');
			for fig = h_figs'
 				if strcmp(get(fig,'Tag'),'model')  
            	figure(fig);  
               print;
               break;
         	end         	
         end
      end                      
      
   case 'FileSave'
  		h_figs = get(0,'children');
		for fig = h_figs'
 			if strcmp(get(fig,'Tag'),'Save_As');
      		delete (fig);  
  			end
		end
      
		h_figs = get(0,'children');
		for fig = h_figs'
 			if strcmp(get(fig,'Tag'),'design');
      		h_design = fig;  
  			end
		end
      
      h_file = findobj(h_design,'Tag','File');         
      if h_file > 1
			name = get(h_file,'String');
		else
   		name = '';
		end 
     
      if prod(size(name)) == 0 % New Model
         Save_As;
      else
         dir_msg = pwd;
         msg = [dir_msg,filesep,'models',filesep,name,' already exists.', ...
                '         Do you want to replace it?'];         
         Repl_File(msg);                
      end      
   	 
   case 'SaveAs'
      Save_As;
               
end % switch
   
% Routine to draw the scattering surface of the model    
function PlotModel

	%1: find DESIGN GUI and get number of vertices 
	h_figs = get(0,'children');
	for fig = h_figs'
  		if strcmp(get(fig,'Tag'),'design');
      	h_design = fig;  
  		end
	end
	nvert = str2num(get(findobj(h_design,'Tag','NVert'),'String'));                    
   scale = str2num(get(findobj(h_design,'Tag','Scale'),'String')); 
   
   % check filename or model name      
	h_file = findobj(h_design,'Tag','File');   
	if h_file > 1
		name = get(h_file,'String');
	else
   	name = 'New';
	end  
   % 2 : read coordinates data and scale factor
	coord = zeros(nvert,3);
	for i = 1:nvert
		for j = 1:3
   		coord(i,j) = str2num(get(findobj(h_design,'Tag',['v',num2str(i),num2str(j+1)]),'String'));
   	end
	end   
	scale = str2num(get(findobj(h_design,'Tag','Scale'),'String'));   
   % 3 : find FACETS GUI and get number of triangles/facets
	h_figs = get(0,'children');
	for fig = h_figs'
		if strcmp(get(fig,'Tag'),'facets');
			h_facets = fig;
   	end
	end
	ntria = str2num(get(findobj(h_facets,'Tag','NFacet'),'String'));                  
	% 4 : read facets data
	facet = zeros(ntria,6);
	for i = 1:ntria
		for j = 1:6
   		facet(i,j) = str2num(get(findobj(h_facets,'Tag',['f',num2str(i),num2str(j)]),'String'));
   	end
	end
	% 5 : manipulate coordinates and facets data
	xpts = coord(:,1)*scale;
	ypts = coord(:,2)*scale;
	zpts = coord(:,3)*scale;
      
	nfc   = facet(:,1);  
	node1 = facet(:,2); 	
	node2 = facet(:,3); 
	node3 = facet(:,4);
    
	for i  = 1:ntria 
		pts = [node1(i) node2(i) node3(i)];
		vind(i,:) = pts;       
	end
	x = xpts; 	y = ypts; 	z = zpts;
                  
	% Define position vectors to vertices
	for i = 1:nvert
		r(i,:) = [x(i) y(i) z(i)];
	end                                
      
	% 6: activate MODEL GUI and plot model             
	h_figs = get(0,'children');
	for fig = h_figs'
		if strcmp(get(fig,'Tag'),'model');
			h_model = fig;
      	figure(fig);	% make MODEL GUI the active figure    
   	end
	end
       
	for i = 1:ntria
		X = [x(vind(i,1)) x(vind(i,2)) x(vind(i,3)) x(vind(i,1))];
   	Y = [y(vind(i,1)) y(vind(i,2)) y(vind(i,3)) y(vind(i,1))];
  		Z = [z(vind(i,1)) z(vind(i,2)) z(vind(i,3)) z(vind(i,1))];
   	plot3(X,Y,Z,'b')
   	if i == 1
			hold on
		end
	end      
      
	axis square   
	title(['Triangular Surface of ',name,' Model']);
	xlabel('x');
	ylabel('y');
	zlabel('z');
	xmax = max(xpts); xmin = min(xpts); 
	ymax = max(ypts); ymin = min(ypts);
	zmax = max(zpts); zmin = min(zpts);
	dmax = max([xmax ymax zmax]); 
	dmin = min([xmin ymin zmin]);
	% This is to avoid both a max and min of zero in any one dimension
	xmax = dmax; 	ymax = dmax; 	zmax = dmax;
	xmin = dmin; 	ymin = dmin; 	zmin = dmin;      
	axis([xmin, xmax, ymin, ymax, zmin, zmax]);    
   
% Routine to label vertices of the model 
function LabelVertices

	% 1 : find DESIGN GUI, get number of vertices and scale
  	h_figs = get(0,'children');
	for fig = h_figs'
		if strcmp(get(fig,'Tag'),'design');
	     	h_design = fig;  
   	end
   end      
   nvert = str2num(get(findobj(h_design,'Tag','NVert'),'String'));   
   scale = str2num(get(findobj(h_design,'Tag','Scale'),'String'));   
   % 2: get coordinates
   coord = zeros(nvert,3);
   for i = 1:nvert
     	for j = 1:3
        	coord(i,j) = str2num(get(findobj(h_design,'Tag',['v',num2str(i),num2str(j+1)]),'String'));    
       end
   end
   x = coord(:,1)*scale;
   y = coord(:,2)*scale;
   z = coord(:,3)*scale;
   % 3 : find MODEL GUI and Label Vertices
   h_figs = get(0,'children');
	for fig = h_figs'
		if strcmp(get(fig,'Tag'),'model');
		    h_model = fig;
          figure(fig);	% make MODEL GUI the active figure    
      end
   end
   % 3 : plot the corresponding vertex numbers
   hold on
   for i = 1:nvert
      text(x(i)-max(x)/20,y(i)-max(y)/20,z(i),num2str(i));
   end    
   hold off

% Routine to label the facets of the model 
function LabelFacets

	% 1 : find DESIGN GUI and get number of vertices
 	h_figs = get(0,'children');
 	for fig = h_figs'
 		if strcmp(get(fig,'Tag'),'design');
     		h_design = fig;    
  		end
 	end   
 	nvert = str2num(get(findobj(h_design,'Tag','NVert'),'String'));                   
   scale = str2num(get(findobj(h_design,'Tag','Scale'),'String'));    
   % 2: get coordinates
 	coord = zeros(nvert,3);
 	for i = 1:nvert
  		for j = 1:3
      	coord(i,j) = str2num(get(findobj(h_design,'Tag',['v',num2str(i),num2str(j+1)]),'String'));
   	end
 	end
 	x = coord(:,1)*scale;
 	y = coord(:,2)*scale;
 	z = coord(:,3)*scale;
 	% 3 : find FACETS GUI and get number of triangles
	h_figs = get(0,'children');
 	for fig = h_figs'
		if strcmp(get(fig,'Tag'),'facets');
			h_facets = fig;  
   	end
 	end
 	ntria = str2num(get(findobj(h_facets,'Tag','NFacet'),'String'));  
 	% 4 : get facet data and nodes
 	facet = zeros(ntria,6);
 	for i = 1:ntria
   	for j = 1:6
      	facet(i,j) = str2num(get(findobj(h_facets,'Tag',['f',num2str(i),num2str(j)]),'String'));
    	end
 	end
 	nfc   = facet(:,1);
 	node1 = facet(:,2);
 	node2 = facet(:,3);
 	node3 = facet(:,4);
 	% 5 : find MODEL GUI          
 	h_figs = get(0,'children');
 	for fig = h_figs'
		if strcmp(get(fig,'Tag'),'model');
			h_model = fig;
       	figure(fig);	% make MODEL GUI the active figure    
    	end
 	end
 	% 6 : Compute centroid of face number i
   h = zeros(ntria);
   hold on
   for i = 1:ntria            
     	xav = (x(node1(i)) + x(node2(i)) + x(node3(i))) / 3;
     	yav = (y(node1(i)) + y(node2(i)) + y(node3(i))) / 3;
     	zav = (z(node1(i)) + z(node2(i)) + z(node3(i))) / 3;            
     	h(i) = text(xav,yav,zav,num2str(nfc(i)));   
   end    
   hold off  
   
   % validates azimuth angle entered
function o_ang = getAzimuth(ang_str)
   
   temp = str2num(ang_str);
   if (isempty(temp)) | (temp < -360) | (temp > 360)
      errordlg('Enter an azimuth angle between -360 and 360 degrees.', ...
         		'Azimuth Angle Status', 'error');
      temp = -37.5; % default azimuth 
   elseif (ang_str == 'i' | ang_str == 'j')
      errordlg('Enter an azimuth angle between -360 and 360 degrees.', ...
         		'Azimuth Angle Status', 'error');
      temp = -37.5; 
   end 
   o_ang = temp;
% end getAzimuth  

   % validates elevation angle entered
function o_ang = getElevation(ang_str)
   
   temp = str2num(ang_str);
   if (isempty(temp)) | (temp < -360) | (temp > 360)
      errordlg('Enter an elevation angle between -360 and 360 degrees.', ...
         		'Elevation Angle Status', 'error');
      temp = 30; % default elevation 
   elseif (ang_str == 'i' | ang_str == 'j')
      errordlg('Enter an elevation angle between -360 and 360 degrees.', ...
         		'Elevation Angle Status', 'error');
      temp = 30; 
   end 
   o_ang = temp;
% end getElevation  
