function fig = monostatic(command_str)
% filename: monostatic.m
% Project: POFACETS
% Description: This function displays the CALCULATE MONOSTATIC RCS GUI.
% Author:  Prof. David C. Jenn and Elmo E. Garrido Jr.
% Date:  31 August 2000
% Place: NPS
%
% 	MONOSTATIC RCS GUI

% Delete active GUIs except POFACETS and MONOSTATIC
h_figs = get(0,'children');
for fig = h_figs'
   % delete Design and Bistatic GUIs
    if strcmp(get(fig,'Tag'),'design') | ...
   	 strcmp(get(fig,'Tag'),'facets') | ...
       strcmp(get(fig,'Tag'),'model') | ...
		 strcmp(get(fig,'Tag'),'hlpdsgncoord') | ...
		 strcmp(get(fig,'Tag'),'hlpdsgnfacet') | ...
		 strcmp(get(fig,'Tag'),'hlpmodel') | ...      
       strcmp(get(fig,'Tag'),'Maximum Number of Points') | ...
       strcmp(get(fig,'Tag'),'Repl_File') | ...
       strcmp(get(fig,'Tag'),'Save_As') | ...
       strcmp(get(fig,'Tag'),'Number of Vertices Status') | ...
       strcmp(get(fig,'Tag'),'dsgnFO') | ...   
    	 strcmp(get(fig,'Tag'),'bistatic') | ...
   	 strcmp(get(fig,'Tag'),'BPlot') | ...
       strcmp(get(fig,'Tag'),'BPlot1') | ...
       strcmp(get(fig,'Tag'),'BMessage') | ...
       strcmp(get(fig,'Tag'),'hlpmain') | ...      
    	 strcmp(get(fig,'Tag'),'hlpbistat') 			
   
   		delete(fig); 
   end
end          

if nargin == 0
   command_str = 'initialize';
end

% Initialize the GUI
if strcmp(command_str,'initialize')
   h_figs = get(0,'children');
   fig_exists = 0;
   for fig = h_figs'
      fig_exists = strcmp(get(fig,'Tag'),'monostatic');
      if fig_exists
         figure(fig);
         return;
      end
   end
end

% figure
h0 = figure('Units','normalized', ...
	'Color',[0.8 0.8 0.8], ...
	'MenuBar','none', ...
	'Name',' CALCULATE MONOSTATIC RCS', ...
	'NumberTitle','off', ...
	'PaperPosition',[18 180 576 432], ...
	'PaperUnits','points', ...
	'Position',[0.3457 0.1940 0.5674 0.6523], ...
	'Resize','off', ...
	'Tag','monostatic', ...
   'ToolBar','none');
% listbox
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[1 1 1], ...
	'Callb','mono ListB;', ...
	'CreateFcn',['list = dir([''models'',filesep,''*.*'']);',...
					 'str = {list.name};',...
					 'set(gcbo,''String'',str)'],...   
   'FontN','Arial', ...
	'FontS',0.07, ...
	'Position',[0.0207 0.460 0.3098 0.4749], ...
	'Style','listbox', ...
	'Tag','ListB', ...
   'Value',3);
% frames
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'Position',[0.3494 0.5329 0.6196 0.3992], ...
	'Style','frame', ...
	'Tag','Frame1');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'Position',[0.3494 0.1178 0.6196 0.3992], ...
	'Style','frame', ...
	'Tag','Frame2');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'Position',[0.0207 0.1150 0.3098 0.2500], ...
	'Style','frame', ...
	'Tag','Frame3');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'Position',[0.7040 0.1697 0.0069 0.180], ...
	'Style','frame', ...
	'Tag','Frame5');
% texts
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'FontN','Arial', ...
	'FontS',0.9, ...
	'FontW','bold', ...
	'Horiz','left', ...
	'Position',[0.025 0.945 0.165 0.032], ...
	'String','Model Name:', ...
	'Style','text', ...
	'Tag','StaticText3');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'FontN','Arial', ...
	'FontS',0.7, ...
	'FontW','bold', ...
	'Horiz','left', ...
	'Position',[0.6 0.862 0.075 0.034], ...
	'String','Theta', ...
	'Style','text', ...
	'Tag','StaticText1');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.78 0.8 0.8], ...
	'FontN','Arial', ...
	'FontS',0.7, ...
	'FontW','bold', ...
	'Horiz','left', ...
	'Position',[0.79 0.862 0.037 0.034], ...
	'String','Phi', ...
	'Style','text', ...
	'Tag','StaticText1');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'FontN','Arial', ...
	'FontS',0.6, ...
	'Horiz','left', ...
	'Position',[0.412 0.7685 0.16 0.045], ...
	'String','Starting Angle', ...
	'Style','text', ...
	'Tag','StaticText2');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'FontN','Arial', ...
	'FontS',0.6, ...
	'Horiz','left', ...
	'Position',[0.412 0.6826 0.15 0.045], ...
	'String','Ending Angle', ...
	'Style','text', ...
	'Tag','StaticText2');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'FontN','Arial', ...
	'FontS',0.6, ...
	'Horiz','left', ...
	'Position',[0.412 0.5948 0.18 0.045], ...
	'String','Increment Angle', ...
	'Style','text', ...
	'Tag','StaticText2');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'FontN','Arial', ...
	'FontS',0.8, ...
	'Horiz','left', ...
	'Position',[0.699 0.78 0.04 0.03], ...
	'String','deg', ...
	'Style','text', ...
	'Tag','StaticText2');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'FontN','Arial', ...
	'FontS',0.8, ...
	'Horiz','left', ...
	'Position',[0.699 0.69 0.04 0.03], ...
	'String','deg', ...
	'Style','text', ...
	'Tag','StaticText2');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'FontN','Arial', ...
	'FontS',0.8, ...
	'Horiz','left', ...
	'Position',[0.699 0.60 0.04 0.03], ...
	'String','deg', ...
	'Style','text', ...
	'Tag','StaticText2');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'FontN','Arial', ...
	'FontS',0.8, ...
	'Horiz','left', ...
	'Position',[0.876 0.78 0.04 0.03], ...
	'String','deg', ...
	'Style','text', ...
	'Tag','StaticText2');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'FontN','Arial', ...
	'FontS',0.8, ...
	'Horiz','left', ...
	'Position',[0.876 0.69 0.04 0.03], ...
	'String','deg', ...
	'Style','text', ...
	'Tag','StaticText2');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'FontN','Arial', ...
	'FontS',0.8, ...
	'Horiz','left', ...
	'Position',[0.876 0.60 0.04 0.03], ...
	'String','deg', ...
	'Style','text', ...
	'Tag','StaticText2');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'FontN','Arial', ...
	'FontS',0.8, ...
	'FontW','bold', ...
	'Horiz','center', ...
	'Position',[0.46 0.437 0.42 0.044], ...
	'String','Computational Parameters', ...
	'Style','text', ...
	'Tag','StaticText4');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'FontN','Arial', ...
	'FontS',0.8, ...
	'FontW','bold', ...
	'Horiz','center', ...
	'Position',[0.444 0.35 0.18 0.04], ...
	'String','Taylor Series', ...
	'Style','text', ...
	'Tag','StaticText4');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'FontN','Arial', ...
	'FontS',0.7, ...
	'Horiz','left', ...
	'Position',[0.39 0.269 0.20 0.034], ...
	'String','Length of Region:', ...
	'Style','text', ...
	'Tag','StaticText4');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'FontN','Arial', ...
	'FontS',0.7, ...
	'Horiz','left', ...
	'Position',[0.39 0.195 0.20 0.034], ...
	'String','Number of Terms:', ...
	'Style','text', ...
	'Tag','StaticText4');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName','Arial', ...
	'FontSize',0.6, ...
	'Position',[0.74 0.34 0.20 0.04], ...
	'String','Incident Polarization', ...
	'Style','text', ...
	'Tag','StaticText5');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'FontN','Arial', ...
	'FontS',0.7, ...
	'Horiz','left', ...
	'Position',[0.725 0.2 0.12 0.034], ...   
	'String','Frequency:', ...
	'Style','text', ...
	'Tag','StaticText4');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'FontN','Arial', ...
	'FontS',0.8, ...
	'Horiz','center', ...
	'Position',[0.874 0.15 0.045 0.028], ...
	'String','GHz', ...
	'Style','text', ...
	'Tag','StaticText4');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'FontN','Arial', ...
	'FontS',0.6, ...
	'FontW','bold', ...
	'Position',[0.062 0.29 0.23 0.045], ...
	'String','Surface Roughness', ...
	'Style','text', ...
	'Tag','StaticText4');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'FontN','Arial', ...
	'FontS',0.65, ...
	'Horiz','left', ...
	'Position',[0.035 0.22 0.21 0.04], ...
	'String','Correlation Dist.(m):', ...
	'Style','text', ...
	'Tag','StaticText4');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'FontN','Arial', ...
	'FontS',0.65, ...
	'Horiz','left', ...
	'Position',[0.035 0.15 0.21 0.04], ...
	'String','Standard Dev. (m):', ...
	'Style','text', ...
	'Tag','StaticText4');
% edit boxes
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[1 1 1], ...
	'Callb','mono TStart;', ...
	'FontN','Arial', ...
	'FontS',0.5, ...
	'Position',[0.599 0.7705 0.0861 0.0579], ...
	'String','0', ...
	'Style','edit', ...
	'Tag','TStart');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[1 1 1], ...
	'Callb','mono TStop;', ...
	'FontN','Arial', ...
	'FontS',0.5, ...
	'Position',[0.599 0.6826 0.0861 0.0579], ...
	'String','360', ...
	'Style','edit', ...
	'Tag','TStop');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[1 1 1], ...
	'Callb','mono Delt;', ...
	'FontN','Arial', ...
	'FontS',0.5, ...
	'Position',[0.599 0.5908 0.0861 0.0579], ...
	'String','3', ...
	'Style','edit', ...
	'Tag','Delt');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[1 1 1], ...
	'Callb','mono PStart;', ...
	'FontN','Arial', ...
	'FontS',0.5, ...
	'Position',[0.7745 0.7705 0.0861 0.0579], ...
	'String','0', ...
	'Style','edit', ...
	'Tag','PStart');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[1 1 1], ...
	'Callb','mono PStop;', ...
	'FontN','Arial', ...
	'FontS',0.5, ...
	'Position',[0.7745 0.6826 0.0861 0.0579], ...
	'String','0', ...
	'Style','edit', ...
	'Tag','PStop');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[1 1 1], ...
	'Callb','mono Delp;', ...
	'FontN','Arial', ...
	'FontS',0.5, ...
	'Position',[0.7745 0.5908 0.0861 0.0579], ...
	'String','1', ...
	'Style','edit', ...
	'Tag','Delp');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[1 1 1], ...
	'Callb','mono LRegion;', ...
	'FontN','Arial', ...
	'FontS',0.5, ...
	'Position',[0.5938 0.2615 0.0861 0.0579], ...
	'String','0.05', ...
	'Style','edit', ...
	'Tag','LRegion');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[1 1 1], ...
	'Callb','mono NTerms;', ...
	'FontN','Arial', ...
	'FontS',0.5, ...
	'Position',[0.5955 0.1816 0.0861 0.0579], ...
	'String','5', ...
	'Style','edit', ...
	'Tag','NTerms');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[1 1 1], ...
	'Callb','mono Freq;', ...
	'FontN','Arial', ...
	'FontS',0.5, ...
	'Position',[0.845 0.19 0.1033 0.0519], ...
	'String','0.3', ...
	'Style','edit', ...
	'Tag','Freq');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[1 1 1], ...
	'Callb','mono Corr;', ...
	'FontN','Arial', ...
	'FontS',0.5, ...
	'Position',[0.24 0.210 0.075 0.0519], ...
	'String','0', ...
	'Style','edit', ...
	'Tag','Corr');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[1 1 1], ...
	'Callb','mono Std;', ...
	'FontN','Arial', ...
	'FontS',0.5, ...
	'Position',[0.24 0.14 0.075 0.0519], ...
	'String','0', ...
	'Style','edit', ...
	'Tag','Std');
% pushbuttons
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'Callb','mono LoadFile;', ...
	'FontN','Arial', ...
	'FontS',0.5, ...
	'Position',[0.1532 0.395 0.1773 0.0559], ...
	'String','Load File', ...
	'Tag','LoadFile');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'Callb','mono Calculate;', ...
	'Enable','off', ...
	'FontN','Arial', ...
	'FontS',0.5, ...
	'Position',[0.0477 0.0279 0.2083 0.06], ...
	'String','Calculate RCS', ...
	'Tag','Calculate');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'Callb','mono Print;', ...
	'FontN','Arial', ...
	'FontS',0.5, ...
	'Position',[0.3477 0.0279 0.157 0.06], ...
   'String','Print', ...
	'Tag','Print');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'Callb','mono Close;', ...
	'FontN','Arial', ...
	'FontS',0.5, ...
	'Position',[0.585 0.0279 0.157 0.06], ...
	'String','Close', ...
	'Tag','Close');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'Callb','hlpmono', ...
	'FontN','Arial', ...
	'FontS',0.5, ...
	'Position',[0.8141 0.0279 0.157 0.06], ...
	'String','Help', ...
   'Tag','Help');
% Pop-up Menu
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
   'BackgroundColor',[1 1 1], ...
  	'Callb','mono i_pol', ...
	'FontName','Arial', ...
	'FontSize',0.4, ...
	'ListboxTop',0, ...
	'Position',[0.75 0.278 0.17 0.06], ...
	'String',['Theta (TM-z) ';' Phi (TE-z)  '], ...
	'Style','popupmenu', ...
	'Tag','IncPolar', ...
   'Value',1);
