function fig = pofacets(command_str)
% filename: pofacets.m
% Project: POFACETS
% Description: This function displays the POFACETS Main Menu GUI.
% Author:  Prof. David C. Jenn and Elmo E. Garrido Jr.
% Date:  24 July 2000
% Place: NPS
% Last modified: 11/17/00 
%
% 	POFACETS GUI for version 2.2

if nargin == 0
   command_str = 'initialize';
end

% Initialize the GUI
if strcmp(command_str,'initialize')
   h_figs = get(0,'children');
   fig_exists = 0;
   for fig = h_figs'
      fig_exists = strcmp(get(fig,'Tag'),'pofacets');
      if fig_exists
         figure(fig);
         return;
      end
   end
end

% Figure
h0 = figure('Units','normalized', ...
	'Color',[0.8 0.8 0.8], ...
	'Name','   RCS PREDICTION USING PHYSICAL OPTICS APPROXIMATION', ...
	'NumberTitle','off', ...
	'PaperPosition',[18 180 576 432], ...
	'PaperUnits','points', ...
	'Position',[0.20898 0.20964  0.537 0.579427], ...
   'Resize','off', ...
   'MenuBar','none', ...
   'Tag','Pofacets');
% Frame
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'Position',[0.305 0.86 0.41 0.10], ...
	'Style','frame', ...
   'Tag','Frame1');
% Show pictures of images
hleft = axes('Parent',h0, ...
	'Box','on', ...
   'CameraUpVector',[0 1 0], ...  
	'Color',[1 1 1], ...
   'Position',[0.025 0.735 0.225 0.225], ...
   'Tag','LeftAxis');
[x,map] = imread('Ship.jpg','jpg');
image(x);
colormap(map);
ax1 = gca;
set(ax1,'XTickLabel','', 'YTickLabel','');
hright = axes('Parent',h0, ...
	'Box','on', ...
   'CameraUpVector',[0 1 0], ...  
	'Color',[1 1 1], ...
   'Position',[0.75 0.735 0.225 0.225], ...
   'Tag','RightAxis');
[y,map] = imread('Plane.jpg','jpg');
image(y);
colormap(map);
ax2 = gca;
set(ax2,'XTickLabel','', 'YTickLabel','');
% Title and Texts
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'FontN','Times-Roman', ...
	'FontS',0.8, ...
	'FontW','bold', ...
	'Horiz','left', ...
	'Position',[0.325 0.862 0.302 0.088], ...
	'String','POFACETS', ...
	'Style','text', ...
   'Tag','StaticText1');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'FontN','Times-Roman', ...
	'FontS',0.6, ...
	'FontW','bold', ...
	'Horiz','left', ...
	'Position',[0.63 0.863 0.07 0.05], ...
	'String',' v 2.3', ...
	'Style','text', ...
   'Tag','StaticText1');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'FontN','Times-Roman', ...
	'FontS',0.7, ...
	'Horiz','left', ...
	'Position',[0.485 0.81 0.025 0.04], ...
	'String','by', ...
	'Style','text', ...
	'Tag','StaticText1');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'FontN','Times-Roman', ...
	'FontS',0.7, ...
	'Horiz','left', ...
	'Position',[0.34 0.765 0.35 0.04], ...
	'String','E. E. Garrido Jr. and D. C. Jenn', ...
	'Style','text', ...
	'Tag','StaticText1');
% Menu Pushbuttons: Design Model, Calculate Monostatic RCS, Calculate Bistatic RCS
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
   'Backg',[0.8 0.8 0.8], ...
   'Callb','design', ...
  	'FontN','Arial', ...
	'FontS',0.35, ...
	'FontW','bold', ...
	'Position',[0.08 0.60 0.4 0.09], ...
	'String',' Design Model', ...
	'Tag','Design');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'Callb','monostatic', ...
 	'FontN','Arial', ...
	'FontS',0.35, ...
	'FontW','bold', ...
	'Position',[0.08 0.41 0.4 0.09], ...
	'String','Calculate Monostatic RCS', ...
	'Tag','CalcMono');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'Callb','bistatic', ...
  	'FontN','Arial', ...
	'FontS',0.35, ...
	'FontW','bold', ...
	'Position',[0.08 0.22 0.4 0.09], ...
	'String','Calculate Bistatic RCS', ...
	'Tag','CalcBistatic');
% Text Descriptions of Menu Pushbuttons
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
   'Backg',[0.8 0.8 0.8], ...
  	'FontN','Arial', ...
	'FontS',0.75, ...
	'Horiz','left', ...
	'Position',[0.52 0.64 0.425 0.04], ...
	'String','Create a new target geometry or load', ...
	'Style','text', ...
	'Tag','StaticText4');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
   'Backg',[0.8 0.8 0.8], ...
  	'FontN','Arial', ...
	'FontS',0.75, ...
	'Horiz','left', ...
	'Position',[0.52 0.60 0.40 0.04], ...
	'String','and edit a previously designed model.', ...
	'Style','text', ...
	'Tag','StaticText4');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
   'Backg',[0.8 0.8 0.8], ...
  	'FontN','Arial', ...
	'FontS',0.75, ...
	'Horiz','left', ...
	'Position',[0.52 0.45 0.39 0.04], ...
	'String','Compute the monostatic radar cross', ...
	'Style','text', ...
	'Tag','StaticText3');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
   'Backg',[0.8 0.8 0.8], ...
  	'FontN','Arial', ...
	'FontS',0.75, ...
	'Horiz','left', ...
	'Position',[0.52 0.41 0.23 0.04], ...
	'String','section of the model.', ...
	'Style','text', ...
	'Tag','StaticText3');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
   'Backg',[0.8 0.8 0.8], ...
  	'FontN','Arial', ...
	'FontS',0.75, ...
	'Horiz','left', ...
	'Position',[0.52 0.26 0.37 0.04], ...
	'String','Compute the bistatic radar cross', ...
	'Style','text', ...
	'Tag','StaticText2');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
   'Backg',[0.8 0.8 0.8], ...
  	'FontN','Arial', ...
	'FontS',0.75, ...
	'Horiz','left', ...
	'Position',[0.52 0.22 0.23 0.04], ...
	'String','section of the model.', ...
	'Style','text', ...
	'Tag','StaticText3');
% Pushbuttons  Close and Help
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
   'Backg',[0.8 0.8 0.8], ...
	'Callb',['h_figs = get(0,''children'');', ...
      'delete(h_figs);'], ...
  	'FontN','Arial', ...
	'FontS',0.35, ...
	'Position',[0.52 0.06 0.155 0.0809], ...
   'String','Close', ...
	'Tag','Close');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontU','normalized', ...
	'Backg',[0.8 0.8 0.8], ...
	'Callb','hlpmain', ...
  	'FontN','Arial', ...
	'FontS',0.35, ...
	'Position',[0.727 0.06 0.155 0.0809], ...
	'String','Help', ...
   'Tag','Help');